@@ -113,11 +113,21 @@ class DateParserCA(DateParser):
 #
 #-------------------------------------------------------------------------
 class DateDisplayCA(DateDisplay):
+    """
+    Catalan language date display class. 
+    """
+    # TODO: Translate these month strings:
+    long_months = ( u"", u"January", u"February", u"March", u"April", u"May", 
+                    u"June", u"July", u"August", u"September", u"October", 
+                    u"November", u"December" )
+    
+    short_months = ( u"", u"Jan", u"Feb", u"Mar", u"Apr", u"May", u"Jun",  
+                     u"Jul", u"Aug", u"Sep", u"Oct", u"Nov", u"Dec" )
 
     calendar = (
-        "", u" (Julià)", u" (Hebreu)", 
-        u" (Revolucionari)", u" (Persa)", u" (Islàmic)", 
-        u" (Swedish)" 
+        "", u"Julià", u"Hebreu", 
+        u"Revolucionari", u"Persa", u"Islàmic", 
+        u"Swedish" 
         )
 
     _mod_str = ("", u"abans de ", u"després de ", u"cap a ", "", "", "")
@@ -154,6 +164,7 @@ class DateDisplayCA(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
         
@@ -164,14 +175,17 @@ class DateDisplayCA(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str, u'des de', d1, u'fins a', d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s %s %s %s%s" % (qual_str, u'des de', d1, u'fins a', d2, scal)
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str, u'entre', d1, u'i', d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s %s %s %s%s" % (qual_str, u'entre', d1, u'i', d2, scal)
         else:
             text = self.display_cal[date.get_calendar()](start)
-            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, scal)
 
 #-------------------------------------------------------------------------
 #
