@@ -44,38 +44,99 @@ from _DateHandler import register_datehandler
 
 #-------------------------------------------------------------------------
 #
-# French parser
+# German parser
 #
 #-------------------------------------------------------------------------
 class DateParserDE(DateParser):
 
     month_to_int = DateParser.month_to_int
-    # Always add german and austrian name variants no matter what the current locale is
+    # Always add german and austrian name variants no matter what the current 
+    # locale is
     month_to_int[u"januar"] = 1
     month_to_int[u"jan"]    = 1
     month_to_int[u"jänner"] = 1
     month_to_int[u"jän"]    = 1
-    # Add other common latin, local and historical variants  
+
+    # Add other common latin, 
+
     month_to_int[u"januaris"] = 1
+    month_to_int[u"januarii"] = 1
+    month_to_int[u"januarius"] = 1
+    month_to_int[u"februaris"] = 2
+    month_to_int[u"februarii"] = 2
+    month_to_int[u"februarius"] = 2
+    month_to_int[u"martii"] = 3
+    month_to_int[u"martius"] = 3
+    month_to_int[u"aprilis"] = 4
+    month_to_int[u"maius"] = 5
+    month_to_int[u"maii"] = 5
+    month_to_int[u"junius"] = 6
+    month_to_int[u"junii"] = 6
+    month_to_int[u"julius"] = 7
+    month_to_int[u"julii"] = 7
+    month_to_int[u"augustus"] = 8
+    month_to_int[u"augusti"] = 8
+    month_to_int[u"septembris"] = 9
+    month_to_int[u"7bris"] = 9
+    month_to_int[u"september"] = 9
+    month_to_int[u"october"] = 10
+    month_to_int[u"octobris"] = 10
+    month_to_int[u"8bris"] = 10
+    month_to_int[u"novembris"] = 11
+    month_to_int[u"9bris"] = 11
+    month_to_int[u"november"] = 11
+    month_to_int[u"decembris"] = 12
+    month_to_int[u"10bris"] = 12
+    month_to_int[u"xbris"] = 12
+    month_to_int[u"december"] = 12
+
+    # local and historical variants  
+
     month_to_int[u"jenner"] = 1
     month_to_int[u"feber"]  = 2
-    month_to_int[u"februaris"]  = 2
     month_to_int[u"merz"]  = 3
-    month_to_int[u"aprilis"]  = 4
-    month_to_int[u"maius"]  = 5
-    month_to_int[u"junius"]  = 6
-    month_to_int[u"julius"]  = 7
     month_to_int[u"augst"]  = 8
     month_to_int[u"7ber"]  = 9
-    month_to_int[u"7bris"]  = 9
     month_to_int[u"8ber"]  = 10
-    month_to_int[u"8bris"]  = 10
     month_to_int[u"9ber"]  = 11
-    month_to_int[u"9bris"]  = 11
     month_to_int[u"10ber"]  = 12
-    month_to_int[u"10bris"]  = 12
     month_to_int[u"xber"]  = 12
-    month_to_int[u"xbris"]  = 12
+
+    # old german names
+
+    month_to_int[u"hartung"] = 1
+    month_to_int[u"eismond"] = 1
+    month_to_int[u"hornung"] = 2
+    month_to_int[u"schmelzmond"] = 2
+    month_to_int[u"taumond"] = 2
+    month_to_int[u"narrenmond"] = 2
+    month_to_int[u"rebmond"] = 2
+    month_to_int[u"hintester"] = 2
+    month_to_int[u"lenzing"] = 3
+    month_to_int[u"lenzmond"] = 3
+    month_to_int[u"launing"] = 4
+    month_to_int[u"ostermond"] = 4
+    month_to_int[u"winnemond"] = 5
+    month_to_int[u"weidenmonat"] = 5
+    month_to_int[u"blumenmond"] = 5
+    month_to_int[u"brachet"] = 6
+    month_to_int[u"brachmond"] = 6
+    month_to_int[u"heuert"] = 7
+    month_to_int[u"heumond"] = 7
+    month_to_int[u"ernting"] = 8
+    month_to_int[u"erntemond"] = 8
+    month_to_int[u"bisemond"] = 8
+    month_to_int[u"scheiding"] = 9
+    month_to_int[u"herbstmond"] = 9
+    month_to_int[u"gilbhard"] = 10
+    month_to_int[u"gilbhart"] = 10
+    month_to_int[u"windmond"] = 11
+    month_to_int[u"nebelung"] = 11
+    month_to_int[u"wintermond"] = 11
+    month_to_int[u"julmond"] = 12
+    month_to_int[u"heilmond"] = 12
+    month_to_int[u"christmond"] = 12
+    month_to_int[u"dustermond"] = 12
     
     modifier_to_int = {
         u'vor'    : Date.MOD_BEFORE, 
@@ -99,6 +160,8 @@ class DateParserDE(DateParser):
         u'französisch republikanisch': Date.CAL_FRENCH, 
         u'franz.'         : Date.CAL_FRENCH, 
         u'persisch'       : Date.CAL_PERSIAN, 
+        u'schwedisch'     : Date.CAL_SWEDISH, 
+        u's'              : Date.CAL_SWEDISH, 
         }
 
     quality_to_int = {
@@ -127,14 +190,25 @@ class DateParserDE(DateParser):
 
 #-------------------------------------------------------------------------
 #
-# French display
+# German display
 #
 #-------------------------------------------------------------------------
 class DateDisplayDE(DateDisplay):
+    """
+    German language date display class. 
+    """
+    
+    long_months = (  u"", u"Januar", u"Februar", u"März", u"April", u"Mai", 
+                    u"Juni", u"Juli", u"August", u"September", u"Oktober", 
+                    u"November", u"Dezember" )
+    
+    short_months = ( u"", u"Jan", u"Feb", u"Mär", u"Apr", u"Mai", u"Jun",  
+                     u"Jul", u"Aug", u"Sep", u"Okt", u"Nov", u"Dez" )
 
     calendar = (
-        "", u" (julianisch)", u" (hebräisch)", 
-        u" (französisch republikanisch)", u" (persisch)", u" (islamisch)"
+        "", u"julianisch", u"hebräisch", 
+        u"französisch republikanisch", u"persisch", u"islamisch", 
+        u"schwedisch" 
         )
 
     _mod_str = ("", u"vor ", u"nach ", u"etwa ", "", "", "")
@@ -156,7 +230,7 @@ class DateDisplayDE(DateDisplay):
             if date_val[3]:
                 return self.display_iso(date_val)
             else:
-                if date_val[0] == 0 and date_val[1] == 0:
+                if date_val[0] == date_val[1] == 0:
                     value = str(date_val[2])
                 else:
                     value = self._tformat.replace('%m', str(date_val[1]))
@@ -168,36 +242,40 @@ class DateDisplayDE(DateDisplay):
                 if date_val[1] == 0:
                     value = year
                 else:
-                    value = "%s %s" % (self._months[date_val[1]], year)
+                    value = "%s %s" % (self.long_months[date_val[1]], year)
             else:
-                value = "%s %d, %s" % (self._months[date_val[1]], date_val[0], year)
+                value = "%s %d, %s" % (self.long_months[date_val[1]], 
+                                       date_val[0], year)
         elif self.format == 3:
             # MON Day, Year
             if date_val[0] == 0:
                 if date_val[1] == 0:
                     value = year
                 else:
-                    value = "%s %s" % (self.MONS[date_val[1]], year)
+                    value = "%s %s" % (self.short_months[date_val[1]], year)
             else:
-                value = "%s %d, %s" % (self.MONS[date_val[1]], date_val[0], year)
+                value = "%s %d, %s" % (self.short_months[date_val[1]], 
+                                       date_val[0], year)
         elif self.format == 4:
             # Day Month Year
             if date_val[0] == 0:
                 if date_val[1] == 0:
                     value = year
                 else:
-                    value = "%s %s" % (self._months[date_val[1]], year)
+                    value = "%s %s" % (self.long_months[date_val[1]], year)
             else:
-                value = "%d. %s %s" % (date_val[0], self._months[date_val[1]], year)
+                value = "%d. %s %s" % (date_val[0], 
+                                       self.long_months[date_val[1]], year)
         else:
             # Day MON Year
             if date_val[0] == 0:
                 if date_val[1] == 0:
                     value = year
                 else:
-                    value = "%s %s" % (self.MONS[date_val[1]], year)
+                    value = "%s %s" % (self.short_months[date_val[1]], year)
             else:
-                value = "%d. %s %s" % (date_val[0], self.MONS[date_val[1]], year)
+                value = "%d. %s %s" % (date_val[0], 
+                                       self.short_months[date_val[1]], year)
         if date_val[2] < 0:
             return self._bce_str % value
         else:
@@ -211,6 +289,7 @@ class DateDisplayDE(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
         
@@ -221,20 +300,23 @@ class DateDisplayDE(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str, u'von', d1, u'bis', d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s %s %s %s%s" % (qual_str, u'von', d1, u'bis', d2, scal)
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%szwischen %s und %s%s" % (qual_str, d1, d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%szwischen %s und %s%s" % (qual_str, d1, d2, scal)
         else:
             text = self.display_cal[date.get_calendar()](start)
-            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, scal)
 
 #-------------------------------------------------------------------------
 #
 # Register classes
 #
 #-------------------------------------------------------------------------
-register_datehandler(('de_DE', 'german', 'de_AT', 'de_CH', 
+register_datehandler(('de_DE', 'german', 'German', 'de_AT', 'de_CH', 
                       'de_LI', 'de_LU', 'de_BE', 'de'), 
                      DateParserDE, DateDisplayDE)
