@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 12946 2009-08-10 14:56:18Z romjerome $
+# $Id: __init__.py 14766 2010-03-11 21:39:39Z borilg $
 
 """
 Class handling language-specific selection for date parser and displayer.
@@ -29,6 +29,7 @@ from _DateHandler import (LANG, LANG_SHORT, LANG_TO_PARSER, LANG_TO_DISPLAY,
                           register_datehandler)
 
 # Import all the localized handlers
+import _Date_bg
 import _Date_ca
 import _Date_cs
 import _Date_de
@@ -59,13 +60,10 @@ except:
 
 # Initialize global displayer
 try:
-    import Config
-    val = Config.get_date_format(LANG_TO_DISPLAY[LANG].formats)
+    import config
+    val = config.get('preferences.date-format')
 except:
-    try:
-        val = Config.get_date_format(LANG_TO_DISPLAY["C"].formats)
-    except:
-        val = 0
+    val = 0
 
 try:
     if LANG in LANG_TO_DISPLAY:
