@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _IsChildOfFilterMatch.py 10874 2008-07-17 18:10:32Z gbritton $
+# $Id: _IsChildOfFilterMatch.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -50,17 +50,16 @@ class IsChildOfFilterMatch(MatchesFilter):
 
     def prepare(self,db):
         self.db = db
-        self.map = {}
+        self.map = set()
         filt = MatchesFilter(self.list)
         filt.prepare(db)
-        for person_handle in db.get_person_handles(sort_handles=False):
-            person = db.get_person_from_handle( person_handle)
-            if filt.apply (db, person):
-                self.init_list (person)
+        for person in db.iter_people():
+            if filt.apply(db, person):
+                self.init_list(person)
         filt.reset()
 
     def reset(self):
-        self.map = {}
+        self.map.clear()
 
     def apply(self,db,person):
         return person.handle in self.map
@@ -70,5 +69,5 @@ class IsChildOfFilterMatch(MatchesFilter):
             return
         for fam_id in person.get_family_handle_list():
             fam = self.db.get_family_from_handle(fam_id)
-            for child_ref in fam.get_child_ref_list():
-                self.map[child_ref.ref] = 1
+            self.map.update(child_ref.ref
+                for child_ref in fam.get_child_ref_list())
