@@ -1,7 +1,8 @@
 #
 # Gramps - a GTK+/GNOME based genealogy program
 #
-# Copyright (C) 2002-2006  Donald N. Allingham
+# Copyright (C) 2002-2007  Donald N. Allingham
+# Copyright (C) 2007-2008  Brian G. Matherly
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,29 +19,37 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: __init__.py 9928 2008-01-24 20:38:10Z acraphae $
+# $Id: __init__.py 13958 2010-01-02 12:33:18Z gburto01 $
 
 """
 Package providing filter rules for GRAMPS.
 """
 
 from _AllSources import AllSources
+from _HasGallery import HasGallery
 from _HasIdOf import HasIdOf
 from _RegExpIdOf import RegExpIdOf
+from _HasNote import HasNote
 from _HasNoteRegexp import HasNoteRegexp
 from _HasNoteMatchingSubstringOf import HasNoteMatchingSubstringOf
 from _HasReferenceCountOf import HasReferenceCountOf
 from _SourcePrivate import SourcePrivate
 from _MatchesFilter import MatchesFilter
 from _HasSource import HasSource
+from _ChangedSince import ChangedSince
+from _HasRepository import HasRepository
 
 editor_rule_list = [
     AllSources,
+    HasGallery,
     HasIdOf,
     RegExpIdOf,
+    HasNote,
     HasNoteRegexp,
     HasNoteMatchingSubstringOf,
     HasReferenceCountOf,
     SourcePrivate,
     MatchesFilter,
+    ChangedSince,
+    HasRepository
 ]
