@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasNoteRegexBase.py 11037 2008-09-07 11:08:18Z gburto01 $
+# $Id: _HasNoteRegexBase.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 #-------------------------------------------------------------------------
 #
@@ -26,7 +26,7 @@
 #
 #-------------------------------------------------------------------------
 import re
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
