@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _SidebarFilter.py 13368 2009-10-13 19:20:35Z gbritton $
+# $Id: _SidebarFilter.py 14248 2010-02-06 16:08:10Z dsblank $
 
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 import gtk
 import pango
 
-import widgets
-import Config
+from gui import widgets
+import config
 
 _RETURN = gtk.gdk.keyval_from_name("Return")
 _KP_ENTER = gtk.gdk.keyval_from_name("KP_Enter")
@@ -34,7 +34,7 @@ class SidebarFilter(object):
     _FILTER_WIDTH = 200
     _FILTER_ELLIPSIZE = pango.ELLIPSIZE_END
 
-    def __init__(self, dbstate, uistate):
+    def __init__(self, dbstate, uistate, namespace):
         self.position = 1
         self.table = gtk.Table(4, 11)
         self.table.set_border_width(6)
@@ -48,6 +48,7 @@ class SidebarFilter(object):
         uistate.connect('filters-changed', self.on_filters_changed)
         self.uistate = uistate
         self.dbstate = dbstate
+        self.namespace = namespace
 
     def _init_interface(self):
         self.table.attach(widgets.MarkupLabel(_('<b>Filter</b>')),
@@ -91,8 +92,8 @@ class SidebarFilter(object):
                           xoptions=gtk.FILL, yoptions=0)
 
     def btn_clicked(self, obj):
-        Config.set(Config.FILTER, False)
-        Config.sync()
+        config.set('interface.filter', False)
+        config.save()
 
     def get_widget(self):
         return self.table
@@ -138,3 +139,48 @@ class SidebarFilter(object):
     def on_filters_changed(self, namespace):
         pass
 
+    def add_filter_entry(self, text, widget):
+        """
+        Adds the text and widget to GUI, with an Edit button.
+        """
+        hbox = gtk.HBox()
+        hbox.pack_start(widget)
+        hbox.pack_start(widgets.SimpleButton(gtk.STOCK_EDIT, self.edit_filter))
+        self.add_entry(text, hbox)
+
+    def edit_filter(self, obj):
+        """
+        Callback which invokes the EditFilter dialog. Will create new
+        filter if called if none is selected.
+        """
+        from gui.filtereditor import EditFilter
+        from Filters import FilterList, GenericFilterFactory
+        import const
+        the_filter = None
+        filterdb = FilterList(const.CUSTOM_FILTERS)
+        filterdb.load()
+        if self.generic.get_active() != 0:
+            model = self.generic.get_model()
+            node = self.generic.get_active_iter()
+            if node:
+                sel_filter = model.get_value(node, 1)
+                # the_filter needs to be a particular object for editor
+                for filt in filterdb.get_filters(self.namespace):
+                    if filt.get_name() == sel_filter.get_name():
+                        the_filter = filt
+        else:
+            the_filter = GenericFilterFactory(self.namespace)()
+        if the_filter:
+            EditFilter(self.namespace, self.dbstate, self.uistate, [],
+                       the_filter, filterdb,
+                       lambda : self.edit_filter_save(filterdb))
+
+    def edit_filter_save(self, filterdb):
+        """
+        If a filter changed, save them all. Reloads, and also calls callback.
+        """
+        from Filters import reload_custom_filters
+        filterdb.save()
+        reload_custom_filters()
+        self.on_filters_changed(self.namespace)
+
