@@ -37,8 +37,6 @@ import tempfile
 # GTK/Gnome modules
 #
 #-------------------------------------------------------------------------
-import gtk
-import gobject
 
 #-------------------------------------------------------------------------
 #
@@ -50,15 +48,16 @@ def resize_to_jpeg(source, destination, width, height):
     Create the destination, derived from the source, resizing it to the
     specified size, while converting to JPEG.
 
-    @param source: source image file, in any format that gtk recognizes
-    @type source: unicode
-    @param destination: destination image file, output written in jpeg format
-    @type destination: unicode
-    @param width: desired width of the destination image
-    @type width: int
-    @param height: desired height of the destination image
-    @type height: int
+    :param source: source image file, in any format that gtk recognizes
+    :type source: unicode
+    :param destination: destination image file, output written in jpeg format
+    :type destination: unicode
+    :param width: desired width of the destination image
+    :type width: int
+    :param height: desired height of the destination image
+    :type height: int
     """
+    import gtk
     img = gtk.gdk.pixbuf_new_from_file(source)
     scaled = img.scale_simple(width, height, gtk.gdk.INTERP_BILINEAR)
     scaled.save(destination, 'jpeg')
@@ -72,11 +71,13 @@ def image_size(source):
     """
     Return the width and size of the specified image.
 
-    @param source: source image file, in any format that gtk recongizes
-    @type source: unicode
-    @rtype: tuple(int, int)
-    @returns: a tuple consisting of the width and height
+    :param source: source image file, in any format that gtk recongizes
+    :type source: unicode
+    :rtype: tuple(int, int)
+    :returns: a tuple consisting of the width and height
     """
+    import gtk
+    import gobject
     try:
         img = gtk.gdk.pixbuf_new_from_file(source)
         width = img.get_width()
@@ -96,18 +97,20 @@ def resize_to_jpeg_buffer(source, width, height):
     Loads the image, converting the file to JPEG, and resizing it. Instead of
     saving the file, the data is returned in a buffer.
 
-    @param source: source image file, in any format that gtk recognizes
-    @type source: unicode
-    @param width: desired width of the destination image
-    @type width: int
-    @param height: desired height of the destination image
-    @type height: int
-    @rtype: buffer of data 
-    @returns: jpeg image as raw data
+    :param source: source image file, in any format that gtk recognizes
+    :type source: unicode
+    :param width: desired width of the destination image
+    :type width: int
+    :param height: desired height of the destination image
+    :type height: int
+    :rtype: buffer of data 
+    :returns: jpeg image as raw data
     """
+    import gtk
     filed, dest = tempfile.mkstemp()
     img = gtk.gdk.pixbuf_new_from_file(source)
     scaled = img.scale_simple(int(width), int(height), gtk.gdk.INTERP_BILINEAR)
+    os.close(filed)
     scaled.save(dest, 'jpeg')
     ofile = open(dest, mode='rb')
     data = ofile.read()
