@@ -1,6 +1,7 @@
 # This file is derived from the GPL program "PyPE"
 #
 # Copyright (C) 2003-2006  Josiah Carlson
+# Copyright (C) 2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -48,7 +49,7 @@ class LRU(object):
 
     def __getitem__(self, obj):
         """
-        Return item assocated with Obj
+        Return item associated with Obj
         """
         return self.data[obj].value[1]
 
@@ -74,7 +75,8 @@ class LRU(object):
             lnk.next.prev = None
             self.first = lnk.next
             lnk.next = None
-            del self.data[lnk.value[0]]
+            if lnk.value[0] in self.data:
+                del self.data[lnk.value[0]]
             del lnk
 
     def __delitem__(self, obj):
@@ -144,3 +146,9 @@ class LRU(object):
         Return all items
         """
         return [data[0] for data in self.iteritems()]
+
+    def clear(self):
+        """
+        Empties LRU
+        """
+        self.data.clear()
