@@ -2,8 +2,9 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2007-2008  Brian G. Matherly
-# Copyright (C) 2008       Gary Burton
+# Copyright (C) 2008,2010  Gary Burton
 # Copyright (C) 2008       Craig J. Anderson
+# Copyright (C) 2009       Nick Hall
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _GuiOptions.py 13392 2009-10-22 09:02:45Z ldnp $
+# $Id: _GuiOptions.py 14553 2010-03-01 19:17:59Z nick-h $
 
 """
 Specific option handling for a GUI.
@@ -29,7 +30,7 @@ Specific option handling for a GUI.
 # python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 import os
 import sys
 
@@ -47,12 +48,14 @@ import gobject
 #
 #-------------------------------------------------------------------------
 import Utils
-import widgets
+from gui.utils import ProgressMeter
+from gui.pluginmanager import GuiPluginManager
+from gui import widgets
 import ManagedWindow
 from QuestionDialog import OptionDialog
-from Selectors import selector_factory
-from BasicUtils import name_displayer as _nd
-from Filters import GenericFilter, Rules
+from gui.selectors import SelectorFactory
+from gen.display.name import displayer as _nd
+from Filters import GenericFilterFactory, GenericFilter, Rules
 import gen
 
 #------------------------------------------------------------------------
@@ -107,12 +110,11 @@ class LastNameDialog(ManagedWindow.ManagedWindow):
             # build up the list of surnames, keeping track of the count for each
             # name (this can be a lengthy process, so by passing in the 
             # dictionary we can be certain we only do this once)
-            progress = Utils.ProgressMeter(_('Finding Surnames'))
+            progress = ProgressMeter(_('Finding Surnames'))
             progress.set_pass(_('Finding surnames'), 
                               database.get_number_of_people())
-            for person_handle in database.get_person_handles(False):
+            for person in database.iter_people():
                 progress.step()
-                person = database.get_person_from_handle(person_handle)
                 key = person.get_primary_name().get_surname()
                 count = 0
                 if key in surnames:
@@ -431,7 +433,8 @@ class GuiPersonOption(gtk.HBox):
         self.pack_start(pevt, False)
         self.pack_end(person_button, False)
         
-        person = self.__dbstate.get_active_person()
+        person_handle = self.__uistate.get_active('Person')
+        person = self.__dbstate.db.get_person_from_handle(person_handle)
         if not person:
             person = self.__db.get_default_person()
         self.__update_person(person)
@@ -459,12 +462,13 @@ class GuiPersonOption(gtk.HBox):
             rfilter.add_rule(Rules.Person.HasIdOf([gid]))
         
         # Add the selected person if one exists.
-        active_person = self.__dbstate.get_active_person()
+        person_handle = self.__uistate.get_active('Person')
+        active_person = self.__dbstate.db.get_person_from_handle(person_handle)
         if active_person:
             gid = active_person.get_gramps_id()
             rfilter.add_rule(Rules.Person.HasIdOf([gid]))
 
-        select_class = selector_factory('Person')
+        select_class = SelectorFactory('Person')
         sel = select_class(self.__dbstate, self.__uistate, self.__track, 
                            title=_('Select a person for the report'), 
                            filter=rfilter )
@@ -532,36 +536,43 @@ class GuiFamilyOption(gtk.HBox):
         
     def __initialize_family(self):
         """
-        Find a family to initialize the option with. Any family will do, but
-        try to find a family that the user is likely interested in.
+        Find a family to initialize the option with. If there is no  active
+        family, try to find a family that the user is likely interested in.
         """
         family_list = []
         
-        # First try the family of the active person
-        person = self.__dbstate.get_active_person()
-        if person:
-            family_list = person.get_family_handle_list()
+        # Use the active family if one is selected
+        family = self.__uistate.get_active('Family')
+        if family:
+            family_list = [family]
+            
+        if not family_list:
+            # Next try the family of the active person
+            person_handle = self.__uistate.get_active('Person')
+            person = self.__dbstate.db.get_person_from_handle(person_handle)
+            if person:
+                family_list = person.get_family_handle_list()
             
         if not family_list:
             # Next try the family of the default person in the database.
             person = self.__db.get_default_person()
             if person:
                 family_list = person.get_family_handle_list()
-                
+
         if not family_list:
             # Finally, take any family you can find.
-            family_list = self.__db.get_family_handles()
-            
-        if family_list:
-            family = self.__db.get_family_from_handle(family_list[0])
-            self.__update_family(family)
+            for family in self.__db.iter_family_handles():
+                self.__update_family(family)
+                break
+        else:
+            self.__update_family(family_list[0])
 
     def __get_family_clicked(self, obj): # IGNORE:W0613 - obj is unused
         """
         Handle the button to choose a different family.
         """
         # Create a filter for the person selector.
-        rfilter = GenericFilter()
+        rfilter = GenericFilterFactory('Family')()
         rfilter.set_logical_op('or')
         
         # Add the current family
@@ -588,17 +599,19 @@ class GuiFamilyOption(gtk.HBox):
                 gid = family.get_gramps_id()
                 rfilter.add_rule(Rules.Family.HasIdOf([gid]))
 
-        select_class = selector_factory('Family')
+        select_class = SelectorFactory('Family')
         sel = select_class(self.__dbstate, self.__uistate, self.__track, 
                            filter=rfilter )
         family = sel.run()
-        self.__update_family(family)
+        if family:
+            self.__update_family(family.get_handle())
     
-    def __update_family(self, family):
+    def __update_family(self, handle):
         """
         Update the currently selected family.
         """
-        if family:
+        if handle:
+            family = self.__dbstate.db.get_family_from_handle(handle)
             family_id = family.get_gramps_id()
             fhandle = family.get_father_handle()
             mhandle = family.get_mother_handle()
@@ -676,7 +689,7 @@ class GuiNoteOption(gtk.HBox):
         """
         Handle the button to choose a different note.
         """
-        select_class = selector_factory('Note')
+        select_class = SelectorFactory('Note')
         sel = select_class(self.__dbstate, self.__uistate, self.__track)
         note = sel.run()
         self.__update_note(note)
@@ -758,7 +771,7 @@ class GuiMediaOption(gtk.HBox):
         """
         Handle the button to choose a different note.
         """
-        select_class = selector_factory('MediaObject')
+        select_class = SelectorFactory('MediaObject')
         sel = select_class(self.__dbstate, self.__uistate, self.__track)
         media = sel.run()
         self.__update_media(media)
@@ -877,7 +890,7 @@ class GuiPersonListOption(gtk.HBox):
             skip_list.add(person.get_handle())
             i = self.__model.iter_next(i)
 
-        select_class = selector_factory('Person')
+        select_class = SelectorFactory('Person')
         sel = select_class(self.__dbstate, self.__uistate, 
                            self.__track, skip=skip_list)
         person = sel.run()
@@ -1017,7 +1030,7 @@ class GuiPlaceListOption(gtk.HBox):
             skip_list.add(place.get_handle())
             i = self.__model.iter_next(i)
 
-        select_class = selector_factory('Place')
+        select_class = SelectorFactory('Place')
         sel = select_class(self.__dbstate, self.__uistate, 
                            self.__track, skip=skip_list)
         place = sel.run()
@@ -1226,6 +1239,9 @@ class GuiDestinationOption(gtk.HBox):
         
         self.__option.connect('options-changed', self.__option_changed)
         
+        self.__option.connect('avail-changed', self.__update_avail)
+        self.__update_avail()
+        
     def __text_changed(self, obj): # IGNORE:W0613 - obj is unused
         """
         Handle the change of the value.
@@ -1287,6 +1303,13 @@ class GuiDestinationOption(gtk.HBox):
         
         self.__entry.set_text( self.__option.get_value() )
         
+    def __update_avail(self):
+        """
+        Update the availability (sensitivity) of this widget.
+        """
+        avail = self.__option.get_available()
+        self.set_sensitive(avail)
+        
 #-------------------------------------------------------------------------
 #
 # GuiStyleOption class
@@ -1315,9 +1338,9 @@ class GuiStyleOption(GuiEnumeratedListOption):
         """The user has clicked on the 'Edit Styles' button.  Create a
         style sheet editor object and let them play.  When they are
         done, update the displayed styles."""
-        import BaseDoc
+        from gen.plug.docgen import StyleSheetList
         from ReportBase._StyleEditor import StyleListDisplay
-        style_list = BaseDoc.StyleSheetList(self.__option.get_style_file(), 
+        style_list = StyleSheetList(self.__option.get_style_file(), 
                                             self.__option.get_default_style())
         StyleListDisplay(style_list, None, None)
 
@@ -1326,6 +1349,63 @@ class GuiStyleOption(GuiEnumeratedListOption):
             new_items.append( (style_name, style_name) )
         self.__option.set_items(new_items)
 
+#-------------------------------------------------------------------------
+#
+# GuiBooleanListOption class
+#
+#-------------------------------------------------------------------------
+class GuiBooleanListOption(gtk.HBox):
+    """
+    This class displays an option that provides a list of check boxes.
+    Each possible value is assigned a value and a description.
+    """
+    def __init__(self, option, dbstate, uistate, track):
+        gtk.HBox.__init__(self)
+        self.__option = option
+        self.__cbutton = []
+
+        COLUMNS = 2 # Number of checkbox columns
+        column = []
+        for i in range(COLUMNS):
+            vbox = gtk.VBox()
+            self.pack_start(vbox, True, True)
+            column.append(vbox)
+            vbox.show()
+
+        counter = 0
+        default = option.get_value().split(',')
+        for description in option.get_descriptions():
+            button = gtk.CheckButton(description)
+            self.__cbutton.append(button)
+            if default[counter] == 'True':
+                button.set_active(True)
+            button.connect("toggled", self.__value_changed)
+            column[counter % COLUMNS].pack_start(button, True, True)
+            button.show()
+            counter += 1
+ 
+        self.set_tooltip_text(self.__option.get_help())
+        
+        self.__option.connect('avail-changed', self.__update_avail)
+        self.__update_avail()
+        
+    def __value_changed(self, button):
+        """
+        Handle the change of the value.
+        """
+        value = ''
+        for button in self.__cbutton:
+            value = value + str(button.get_active()) + ','
+        value = value[:len(value)-1]
+        self.__option.set_value(value)
+        
+    def __update_avail(self):
+        """
+        Update the availability (sensitivity) of this widget.
+        """
+        avail = self.__option.get_available()
+        self.set_sensitive(avail)
+
 #------------------------------------------------------------------------
 #
 # GuiMenuOptions class
@@ -1386,7 +1466,7 @@ class GuiMenuOptions(object):
                 if name in self.options_dict:
                     option.set_value(self.options_dict[name])
                     
-                widget, label = make_gui_option(option, dialog.dbstate, 
+                widget, label = make_gui_option(option, dialog.dbstate,
                                                 dialog.uistate, dialog.track)
 
                 if widget is None:
@@ -1414,7 +1494,7 @@ def make_gui_option(option, dbstate, uistate, track):
     """
     widget = None
     label = True
-    pmgr = gen.plug.PluginManager.get_instance()
+    pmgr = GuiPluginManager.get_instance()
     external_options = pmgr.get_external_opt_dict()
     if isinstance(option, gen.plug.menu.PersonOption):
         widget = GuiPersonOption(option, dbstate, uistate, track)
@@ -1447,6 +1527,8 @@ def make_gui_option(option, dbstate, uistate, track):
         widget = GuiSurnameColorOption(option, dbstate, uistate, track)
     elif isinstance(option, gen.plug.menu.PlaceListOption):
         widget = GuiPlaceListOption(option, dbstate, uistate, track)
+    elif isinstance(option, gen.plug.menu.BooleanListOption):
+        widget = GuiBooleanListOption(option, dbstate, uistate, track)
     elif option.__class__ in external_options:
         widget = external_options[option.__class__](option, dbstate, uistate,
                                                     track)
@@ -1454,4 +1536,3 @@ def make_gui_option(option, dbstate, uistate, track):
         raise AttributeError(
                      "can't make GuiOption: unknown option type: '%s'" % option)
     return widget, label
-
