@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _CommandLineReport.py 12805 2009-07-16 12:40:52Z bmcage $
+# $Id: _CommandLineReport.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 
 #-------------------------------------------------------------------------
@@ -29,7 +29,9 @@
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
+import traceback
+import os
 import sys
 
 import logging
@@ -40,15 +42,22 @@ log = logging.getLogger(".")
 # Gramps modules
 #
 #-------------------------------------------------------------------------
-import gen
 import Utils
-import BaseDoc
-from BasicUtils import name_displayer
-from ReportBase import CATEGORY_TEXT, CATEGORY_DRAW, CATEGORY_BOOK, \
-    CATEGORY_GRAPHVIZ
+from gen.plug import BasePluginManager
+from gen.plug.docgen import (StyleSheet, StyleSheetList, PaperStyle,
+                             PAPER_PORTRAIT, PAPER_LANDSCAPE)
+from gen.plug.menu import (FamilyOption, PersonOption, NoteOption, 
+                           MediaOption, PersonListOption, NumberOption, 
+                           BooleanOption, DestinationOption, StringOption, 
+                           TextOption, EnumeratedListOption)
+from gen.display.name import displayer as name_displayer
+from Errors import ReportError
+from ReportBase import (CATEGORY_TEXT, CATEGORY_DRAW, CATEGORY_BOOK,
+                        CATEGORY_GRAPHVIZ, CATEGORY_CODE)
 from _PaperMenu import paper_sizes
-import os
 import const
+import DbState
+from cli.grampscli import CLIManager
 
 #------------------------------------------------------------------------
 #
@@ -64,26 +73,27 @@ def _validate_options(options, dbase):
     dbase: the database the options will be applied to
     """
     if not hasattr(options, "menu"):
+        print 'no menu'
         return
     menu = options.menu
     
     for name in menu.get_all_option_names():
         option = menu.get_option_by_name(name)
 
-        if isinstance(option, gen.plug.menu.PersonOption):
+        if isinstance(option, PersonOption):
             pid = option.get_value()
             person = dbase.get_person_from_gramps_id(pid)
             if not person:
                 person = dbase.get_default_person()
                 if not person:
-                    phandle = dbase.get_person_handles()[0]
+                    phandle = dbase.iter_person_handles().next()
                     person = dbase.get_person_from_handle(phandle)
                     if not person:
                         print "ERROR: Please specify a person"
             if person:
                 option.set_value(person.get_gramps_id())
             
-        elif isinstance(option, gen.plug.menu.FamilyOption):
+        elif isinstance(option, FamilyOption):
             fid = option.get_value()
             family = dbase.get_family_from_gramps_id(fid)
             if not family:
@@ -95,16 +105,13 @@ def _validate_options(options, dbase):
                 if family_list:
                     family_handle = family_list[0]
                 else:
-                    flist = dbase.get_family_handles()
-                    if flist:
-                        family_handle = flist[0]
+                    family_handle = dbase.iter_family_handles().next()
                 if family_handle:
                     family = dbase.get_family_from_handle(family_handle)
                     option.set_value(family.get_gramps_id())
                 else:
                     print "ERROR: Please specify a family"
 
-
 #------------------------------------------------------------------------
 #
 # Command-line report
@@ -117,6 +124,21 @@ class CommandLineReport(object):
 
     def __init__(self, database, name, category, option_class, options_str_dict,
                  noopt=False):
+        
+        pmgr = BasePluginManager.get_instance()
+        self.__textdoc_plugins = []
+        self.__drawdoc_plugins = []
+        self.__bookdoc_plugins = []
+        for plugin in pmgr.get_docgen_plugins():
+            if plugin.get_text_support() and plugin.get_extension():
+                self.__textdoc_plugins.append(plugin)
+            if plugin.get_draw_support() and plugin.get_extension():
+                self.__drawdoc_plugins.append(plugin)
+            if plugin.get_text_support() and \
+               plugin.get_draw_support() and \
+               plugin.get_extension():
+                self.__bookdoc_plugins.append(plugin)
+        
         self.database = database
         self.category = category
         self.format = None
@@ -134,11 +156,6 @@ class CommandLineReport(object):
         """
         Initialize the options that are hard-coded into the report system.
         """
-        pmgr = gen.plug.PluginManager.get_instance()
-        _textdoc_list = pmgr.get_text_doc_list()
-        _drawdoc_list = pmgr.get_draw_doc_list()
-        _bookdoc_list = pmgr.get_book_doc_list()
-        
         self.options_dict = {
             'of'        : self.option_class.handler.module_name,
             'off'       : self.option_class.handler.get_format_name(),
@@ -146,16 +163,17 @@ class CommandLineReport(object):
                     self.option_class.handler.get_default_stylesheet_name(),
             'papers'    : self.option_class.handler.get_paper_name(),
             'papero'    : self.option_class.handler.get_orientation(),
-            'template'  : self.option_class.handler.get_template_name(),
+            'css'       : self.option_class.handler.get_css_filename(),
             }
 
         self.options_help = {
             'of'        : ["=filename", "Output file name. MANDATORY", ""],
-            'off'       : ["=format", "Output file format.", ""],
+            'off'       : ["=format", "Output file format.", []],
             'style'     : ["=name", "Style name.", ""],
             'papers'    : ["=name", "Paper size name.", ""],
             'papero'    : ["=num", "Paper orientation number.", ""],
-            'template'  : ["=name", "Template name (HTML only).", ""],
+            'css'       : ["=css filename", "CSS filename to use, html format"
+                            " only", ""],
             }
 
         if noopt:
@@ -165,14 +183,17 @@ class CommandLineReport(object):
                                                   "whatever_name")
 
         if self.category == CATEGORY_TEXT:
-            self.options_help['off'][2] = \
-                [ item[6] for item in _textdoc_list ]
+            for plugin in self.__textdoc_plugins:
+                self.options_help['off'][2].append( 
+                    plugin.get_extension() + "\t" + plugin.get_description() )
         elif self.category == CATEGORY_DRAW:
-            self.options_help['off'][2] = \
-                [ item[6] for item in _drawdoc_list ]
+            for plugin in self.__drawdoc_plugins:
+                self.options_help['off'][2].append(  
+                    plugin.get_extension() + "\t" + plugin.get_description() )
         elif self.category == CATEGORY_BOOK:
-            self.options_help['off'][2] = \
-                [ item[6] for item in _bookdoc_list ]
+            for plugin in self.__bookdoc_plugins:
+                self.options_help['off'][2].append(  
+                    plugin.get_extension() + "\t" + plugin.get_description() )
         else:
             self.options_help['off'][2] = "NA"
 
@@ -181,19 +202,19 @@ class CommandLineReport(object):
                         if paper.get_name() != _("Custom Size") ]
 
         self.options_help['papero'][2] = [
-            "%d\tPortrait" % BaseDoc.PAPER_PORTRAIT,
-            "%d\tLandscape" % BaseDoc.PAPER_LANDSCAPE ]
+            "%d\tPortrait" % PAPER_PORTRAIT,
+            "%d\tLandscape" % PAPER_LANDSCAPE ]
 
-        self.options_help['template'][2] = os.path.join(const.USER_HOME,
-                                                          "whatever_name")
+        self.options_help['css'][2] = os.path.join(const.USER_HOME,
+                                                   "whatever_name.css")
 
         if self.category in (CATEGORY_TEXT, CATEGORY_DRAW):
-            default_style = BaseDoc.StyleSheet()
+            default_style = StyleSheet()
             self.option_class.make_default_style(default_style)
 
             # Read all style sheets available for this item
             style_file = self.option_class.handler.get_stylesheet_savefile()
-            self.style_list = BaseDoc.StyleSheetList(style_file, default_style)
+            self.style_list = StyleSheetList(style_file, default_style)
             
             self.options_help['style'][2] = self.style_list.get_style_names()
             
@@ -209,7 +230,7 @@ class CommandLineReport(object):
             self.options_dict[name] = option.get_value()
             self.options_help[name] = [ "", option.get_help() ]
             
-            if isinstance(option, gen.plug.menu.PersonOption):
+            if isinstance(option, PersonOption):
                 id_list = []
                 for person_handle in self.database.get_person_handles():
                     person = self.database.get_person_from_handle(person_handle)
@@ -217,10 +238,9 @@ class CommandLineReport(object):
                         person.get_gramps_id(),
                         name_displayer.display(person)))
                 self.options_help[name].append(id_list)
-            elif isinstance(option, gen.plug.menu.FamilyOption):
+            elif isinstance(option, FamilyOption):
                 id_list = []
-                for fhandle in self.database.get_family_handles():
-                    family = self.database.get_family_from_handle(fhandle)
+                for family in self.database.iter_families():
                     mname = ""
                     fname = ""
                     mhandle = family.get_mother_handle()
@@ -237,31 +257,31 @@ class CommandLineReport(object):
                         (family.get_gramps_id(), fname, mname)
                     id_list.append(text)
                 self.options_help[name].append(id_list)
-            elif isinstance(option, gen.plug.menu.NoteOption):
+            elif isinstance(option, NoteOption):
                 id_list = []
                 for nhandle in self.database.get_note_handles():
                     note = self.database.get_note_from_handle(nhandle)
                     id_list.append(note.get_gramps_id())
                 self.options_help[name].append(id_list)
-            elif isinstance(option, gen.plug.menu.MediaOption):
+            elif isinstance(option, MediaOption):
                 id_list = []
                 for mhandle in self.database.get_media_object_handles():
                     mobject = self.database.get_object_from_handle(mhandle)
                     id_list.append(mobject.get_gramps_id())
                 self.options_help[name].append(id_list)
-            elif isinstance(option, gen.plug.menu.PersonListOption):
+            elif isinstance(option, PersonListOption):
                 self.options_help[name].append("")
-            elif isinstance(option, gen.plug.menu.NumberOption):
+            elif isinstance(option, NumberOption):
                 self.options_help[name].append("A number")
-            elif isinstance(option, gen.plug.menu.BooleanOption):
+            elif isinstance(option, BooleanOption):
                 self.options_help[name].append(["0\tno", "1\tyes"])
-            elif isinstance(option, gen.plug.menu.DestinationOption):
+            elif isinstance(option, DestinationOption):
                 self.options_help[name].append("A file system path")
-            elif isinstance(option, gen.plug.menu.StringOption):
+            elif isinstance(option, StringOption):
                 self.options_help[name].append("Any text")
-            elif isinstance(option, gen.plug.menu.TextOption):
+            elif isinstance(option, TextOption):
                 self.options_help[name].append("Any text")
-            elif isinstance(option, gen.plug.menu.EnumeratedListOption):
+            elif isinstance(option, EnumeratedListOption):
                 ilist = []
                 for (value, description) in option.get_items():
                     ilist.append("%s\t%s" % (value, description))
@@ -277,8 +297,8 @@ class CommandLineReport(object):
             return
         menu = self.option_class.menu
         menu_opt_names = menu.get_all_option_names()
-        for opt in self.options_str_dict.keys():
-            if opt in self.options_dict.keys():
+        for opt in self.options_str_dict:
+            if opt in self.options_dict:
                 converter = Utils.get_type_converter(self.options_dict[opt])
                 self.options_dict[opt] = converter(self.options_str_dict[opt])
                 self.option_class.handler.options_dict[opt] = \
@@ -293,29 +313,29 @@ class CommandLineReport(object):
         
         self.option_class.handler.output = self.options_dict['of']
 
-        pmgr = gen.plug.PluginManager.get_instance()
-
+        self.css_filename = None
         if self.category == CATEGORY_TEXT:
-            for item in pmgr.get_text_doc_list():
-                if item[6] == self.options_dict['off']:
-                    self.format = item[1]
+            for plugin in self.__textdoc_plugins:
+                if plugin.get_extension() == self.options_dict['off']:
+                    self.format = plugin.get_basedoc()
+            self.css_filename = self.options_dict['css']
             if self.format is None:
                 # Pick the first one as the default.
-                self.format = pmgr.get_text_doc_list()[0][1]
+                self.format = self.__textdoc_plugins[0].get_basedoc()
         elif self.category == CATEGORY_DRAW:
-            for item in pmgr.get_draw_doc_list():
-                if item[6] == self.options_dict['off']:
-                    self.format = item[1]
+            for plugin in self.__drawdoc_plugins:
+                if plugin.get_extension() == self.options_dict['off']:
+                    self.format = plugin.get_basedoc()
             if self.format is None:
                 # Pick the first one as the default.
-                self.format = pmgr.get_draw_doc_list()[0][1]
+                self.format = self.__drawdoc_plugins[0].get_basedoc()
         elif self.category == CATEGORY_BOOK:
-            for item in pmgr.get_book_doc_list():
-                if item[6] == self.options_dict['off']:
-                    self.format = item[1]
+            for plugin in self.__bookdoc_plugins:
+                if plugin.get_extension() == self.options_dict['off']:
+                    self.format = plugin.get_basedoc()
             if self.format is None:
                 # Pick the first one as the default.
-                self.format = pmgr.get_book_doc_list()[0][1]
+                self.format = self.__bookdoc_plugins[0].get_basedoc()
         else:
             self.format = None
 
@@ -325,15 +345,14 @@ class CommandLineReport(object):
         self.option_class.handler.set_paper(self.paper)
 
         self.orien = self.options_dict['papero']
-        self.template_name = self.options_dict['template']
 
         if self.category in (CATEGORY_TEXT, CATEGORY_DRAW):
-            default_style = BaseDoc.StyleSheet()
+            default_style = StyleSheet()
             self.option_class.make_default_style(default_style)
 
             # Read all style sheets available for this item
             style_file = self.option_class.handler.get_stylesheet_savefile()
-            self.style_list = BaseDoc.StyleSheetList(style_file,default_style)
+            self.style_list = StyleSheetList(style_file, default_style)
 
             # Get the selected stylesheet
             style_name = self.option_class.handler.get_default_stylesheet_name()
@@ -347,31 +366,26 @@ class CommandLineReport(object):
             return
         elif self.show == 'all':
             print "   Available options:"
-            for key in self.options_dict.keys():
-                if key in self.options_dict.keys():
+            for key in self.options_dict:
+                if key in self.options_help:
+                    opt = self.options_help[key]
                 # Make the output nicer to read, assume that tab has 8 spaces
-                    if len(key) < 10:
-                        print "      %s\t\t%s (%s)" % (key, 
-                                                    self.options_help[key][1], 
-                                                    self.options_help[key][0])
-                    else:
-                        print "      %s\t%s (%s)" % (key, 
-                                                     self.options_help[key][1], 
-                                                     self.options_help[key][0])
+                    tabs = '\t' if len(key) < 10 else '\t'*2
+                    print "      %s%s%s (%s)" % (key, tabs, opt[1], opt[0])
                 else:
                     print " %s" % key
             print "   Use 'show=option' to see description and acceptable values"
-        elif self.show in self.options_dict.keys():
-            print '   %s%s\t%s' % (self.show,
-                                    self.options_help[self.show][0],
-                                    self.options_help[self.show][1])
+        elif self.show in self.options_help:
+            opt = self.options_help[self.show]
+            tabs = '\t' if len(self.show) < 10 else '\t'*2
+            print '   %s%s%s%s' % (self.show, tabs, opt[0], opt[1])
             print "   Available values are:"
-            vals = self.options_help[self.show][2]
+            vals = opt[2]
             if isinstance(vals, (list, tuple)):
                 for val in vals:
                     print "      %s" % val
             else:
-                print "      %s" % self.options_help[self.show][2]
+                print "      %s" % opt[2]
 
         else:
             #there was a show option given, but the option is invalid
@@ -386,6 +400,7 @@ class CommandLineReport(object):
 def cl_report(database, name, category, report_class, options_class, 
               options_str_dict):
     
+    err_msg = _("Failed to write report. ")
     clr = CommandLineReport(database, name, category, options_class, 
                             options_str_dict)
 
@@ -399,12 +414,73 @@ def cl_report(database, name, category, report_class, options_class,
                         CATEGORY_GRAPHVIZ]:
             clr.option_class.handler.doc = clr.format(
                         clr.selected_style,
-                        BaseDoc.PaperStyle(clr.paper,clr.orien),
-                        clr.template_name)
+                        PaperStyle(clr.paper,clr.orien))
+            if clr.css_filename is not None and hasattr(clr.option_class.handler.doc, 'set_css_filename'):
+                clr.option_class.handler.doc.set_css_filename(clr.css_filename)
         MyReport = report_class(database, clr.option_class)
         MyReport.doc.init()
         MyReport.begin_report()
         MyReport.write_report()
         MyReport.end_report()
+        return clr
+    except ReportError, msg:
+        (m1, m2) = msg.messages()
+        print err_msg
+        print m1
     except:
-        log.error("Failed to write report.", exc_info=True)
+        if len(log.handlers) > 0:
+            log.error(err_msg, exc_info=True)
+        else:
+            print >> sys.stderr, err_msg
+            ## Something seems to eat the exception above.
+            ## Hack to re-get the exception:
+            try:
+                raise
+            except:
+                traceback.print_exc()
+
+def run_report(db, name, **options_str_dict):
+    """
+    Given a database, run a given report.
+
+    db is a Db database
+
+    name is the name of a report
+
+    options_str_dict is the same kind of options
+    given at the command line. For example:
+    
+    >>> run_report(db, "ancestor_report", off="txt", 
+                   of="ancestor-007.txt", pid="I37")
+
+    returns CommandLineReport (clr) if successfully runs the report,
+    None otherwise.
+
+    You can see:
+       options and values used in  clr.option_class.options_dict
+       filename in clr.option_class.get_output()
+    """
+    dbstate = DbState.DbState()
+    climanager = CLIManager(dbstate, False) # don't load db
+    climanager.do_reg_plugins()
+    pmgr = BasePluginManager.get_instance()
+    cl_list = pmgr.get_reg_reports()
+    clr = None
+    for pdata in cl_list:
+        if name == pdata.id:
+            mod = pmgr.load_plugin(pdata)
+            if not mod:
+                #import of plugin failed
+                return clr
+            category = pdata.category
+            report_class = getattr(mod, pdata.reportclass)
+            options_class = getattr(mod, pdata.optionclass)
+            if category in (CATEGORY_BOOK, CATEGORY_CODE):
+                options_class(db, name, category, 
+                              options_str_dict)
+            else:
+                clr = cl_report(db, name, category, 
+                                report_class, options_class,
+                                options_str_dict)
+                return clr
+    return clr
