@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: const.py.in 12767 2009-07-06 17:36:36Z bmcage $
+# $Id: const.py.in 15202 2010-04-17 23:21:08Z dsblank $
 
 """
 Provides constants for other modules
@@ -32,8 +32,21 @@ Provides constants for other modules
 #-------------------------------------------------------------------------
 import os
 import sys
+import uuid
 from gettext import gettext as _
 
+#-------------------------------------------------------------------------
+#
+# Gramps Version
+#
+#-------------------------------------------------------------------------
+PROGRAM_NAME   = "Gramps"
+if "3.2.1-1" == "@" + "VERSIONSTRING" + "@":
+    VERSION        = "3.2.1"
+else:
+    VERSION        = "3.2.1-1"
+VERSION_TUPLE  = (3, 2, 1)
+
 #-------------------------------------------------------------------------
 #
 # Standard GRAMPS Websites
@@ -43,10 +56,11 @@ URL_HOMEPAGE    = "http://gramps-project.org/"
 URL_MAILINGLIST = "http://sourceforge.net/mail/?group_id=25770"
 URL_BUGTRACKER  = "http://bugs.gramps-project.org/bug_report_advanced_page.php"
 URL_WIKISTRING  = "http://gramps-project.org/wiki/index.php?title="
-URL_MANUAL_PAGE = "Gramps_3.1_Wiki_Manual"
+URL_MANUAL_PAGE = "Gramps_3.2_Wiki_Manual"
 WIKI_FAQ = "FAQ"
-WIKI_KEYBINDINGS = "Gramps_3.1_Wiki_Manual_-_Keybindings"
-WIKI_EXTRAPLUGINS= "3.1.x_Third-party_Plugins"
+WIKI_KEYBINDINGS = "Gramps_3.2_Wiki_Manual_-_Keybindings"
+WIKI_EXTRAPLUGINS= "3.2_Addons"
+WIKI_EXTRAPLUGINS_RAWDATA = "Plugins3.2&action=raw"
 
 #-------------------------------------------------------------------------
 #
@@ -69,6 +83,17 @@ APP_VCARD       = ["text/x-vcard", "text/x-vcalendar"]
 PREFIXDIR = "/usr/local"
 SYSCONFDIR = "/etc"
 
+#-------------------------------------------------------------------------
+#
+# Platforms
+# Never test on LINUX, handle Linux in the else statement as default
+#
+#-------------------------------------------------------------------------
+LINUX = ["Linux", "linux", "linux2"]
+MACOS = ["Darwin", "darwin"]
+WINDOWS = ["Windows", "win32"]
+
+
 #-------------------------------------------------------------------------
 #
 # Determine the home directory. According to Wikipedia, most UNIX like
@@ -89,6 +114,14 @@ else:
     USER_HOME = os.environ['HOME'] 
     HOME_DIR = os.path.join(USER_HOME, '.gramps')
 
+# Conversion of USER_HOME to unicode was needed to have better
+# support for non ASCII path names in Windows for the Gramps database.
+USER_HOME = unicode(USER_HOME, sys.getfilesystemencoding())
+
+# Tried also coversion of HOME_DIR, but that caused a lot of problems
+# in Windows. Leave it unconverted for now.
+#HOME_DIR = unicode(HOME_DIR, sys.getfilesystemencoding())
+
 #-------------------------------------------------------------------------
 #
 # Paths to files - assumes that files reside in the same directory as
@@ -104,6 +137,8 @@ else:
         unicode(__file__, sys.getfilesystemencoding())))
 
 IMAGE_DIR      = os.path.join(ROOT_DIR, "images")
+VERSION_DIR    = os.path.join(
+    HOME_DIR, "gramps%s%s" % (VERSION_TUPLE[0], VERSION_TUPLE[1]))
 
 CUSTOM_FILTERS = os.path.join(HOME_DIR, "custom_filters.xml")
 REPORT_OPTIONS = os.path.join(HOME_DIR, "report_options.xml")
@@ -111,12 +146,11 @@ TOOL_OPTIONS   = os.path.join(HOME_DIR, "tool_options.xml")
 
 ENV_DIR        = os.path.join(HOME_DIR, "env")
 TEMP_DIR       = os.path.join(HOME_DIR, "temp")
-THUMB_DIR      = os.path.join(HOME_DIR, "thumb")  
-USER_PLUGINS   = os.path.join(HOME_DIR, "plugins")    
-USER_TEMPLATES = os.path.join(HOME_DIR, "templates")    
+THUMB_DIR      = os.path.join(HOME_DIR, "thumb")
+USER_PLUGINS   = os.path.join(VERSION_DIR, "plugins")
 # dirs checked/made for each Gramps session
-USER_DIRLIST = (HOME_DIR, ENV_DIR, TEMP_DIR, THUMB_DIR,
-                USER_PLUGINS, USER_TEMPLATES)
+USER_DIRLIST = (HOME_DIR, VERSION_DIR, ENV_DIR, TEMP_DIR, THUMB_DIR,
+                USER_PLUGINS)
 
 ICON           = os.path.join(ROOT_DIR, "images", "gramps.png")
 LOGO           = os.path.join(ROOT_DIR, "images", "logo.png")
@@ -137,15 +171,15 @@ RULE_GLADE     = os.path.join(GLADE_DIR, "rule.glade")
 
 PLUGINS_DIR    = os.path.join(ROOT_DIR, "plugins")
 DATA_DIR       = os.path.join(ROOT_DIR, "data")
-SYSTEM_FILTERS = os.path.join(DATA_DIR, "system_filters.xml")
-TEMPLATE_DIR   = os.path.join(DATA_DIR, "templates")
+WEB_DIR        = os.path.join(ROOT_DIR, 'web')
+#SYSTEM_FILTERS = os.path.join(DATA_DIR, "system_filters.xml")
 TIP_DATA       = os.path.join(DATA_DIR, "tips.xml")
 
 PAPERSIZE      = os.path.join(DATA_DIR, "papersize.xml")
 
 USE_TIPS       = False
 
-if os.sys.platform == "win32":
+if os.sys.platform in WINDOWS:
     USE_THUMBNAILER = False
 else:
     USE_THUMBNAILER = True
@@ -155,11 +189,9 @@ else:
 # About box information
 #
 #-------------------------------------------------------------------------
-PROGRAM_NAME   = "GRAMPS"
-VERSION        = "3.1.3-1"
 COPYRIGHT_MSG  = u"\u00A9 2001-2006 Donald N. Allingham\n" \
-                 u"\u00A9 2007-2009 The GRAMPS Developers"
-COMMENTS       = _("GRAMPS (Genealogical Research and Analysis "
+                 u"\u00A9 2007-2010 The Gramps Developers"
+COMMENTS       = _("Gramps (Genealogical Research and Analysis "
                    "Management Programming System) is a personal "
                    "genealogy program.")
 AUTHORS        = [
@@ -193,16 +225,6 @@ XMLFILE      = "data.gramps"
 NO_SURNAME   = "(%s)" % _("none")
 NO_GIVEN     = "(%s)" % _("none")
 
-#-------------------------------------------------------------------------
-#
-# Platforms
-# Never test on LINUX, handle Linux in the else statement as default
-#
-#-------------------------------------------------------------------------
-LINUX = ["Linux", "linux"]
-MACOS = ["Darwin", "darwin"]
-WINDOWS = ["Windows", "win32"]
-
 #-------------------------------------------------------------------------
 #
 # Options Constants
@@ -263,4 +285,4 @@ LONGOPTS = [
 
 SHORTOPTS = "O:i:e:f:a:p:d:lLhu?"
 
-
+GRAMPS_UUID =  uuid.UUID('516cd010-5a41-470f-99f8-eb22f1098ad6')
