@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: eventroletype.py 10397 2008-03-25 22:55:58Z zfoldvar $
+# $Id: eventroletype.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 """
 Provide the different event roles.
@@ -28,7 +28,7 @@ Provide the different event roles.
 # Python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -68,3 +68,16 @@ class EventRoleType(GrampsType):
 
     def __init__(self, value=None):
         GrampsType.__init__(self, value)
+
+    def is_primary(self):
+        """
+        Returns True if EventRoleType is PRIMARY, False otherwise.
+        """
+        return self.value == self.PRIMARY
+
+    def is_family(self):
+        """
+        Returns True if EventRoleType is FAMILY, False otherwise.
+        """
+        return self.value == self.FAMILY
+
