@@ -18,12 +18,19 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: private.py 13640 2009-11-19 20:50:17Z bmcage $
+# $Id: private.py 15193 2010-04-17 20:08:47Z dsblank $
 
 """
 Proxy class for the GRAMPS databases. Filter out all data marked private.
 """
 
+#-------------------------------------------------------------------------
+#
+# Python libraries
+#
+#-------------------------------------------------------------------------
+from gen.ggettext import gettext as _
+
 #-------------------------------------------------------------------------
 #
 # GRAMPS libraries
@@ -40,7 +47,7 @@ class PrivateProxyDb(ProxyDbBase):
     but all data marked private will be hidden from the user.
     """
 
-    def __init__(self,db):
+    def __init__(self, db):
         """
         Create a new PrivateProxyDb instance. 
         """
@@ -53,7 +60,7 @@ class PrivateProxyDb(ProxyDbBase):
         """
         person = self.db.get_person_from_handle(handle)
         if person and not person.get_privacy():
-            return sanitize_person(self.db,person)
+            return sanitize_person(self.db, person)
         return None
 
     def get_source_from_handle(self, handle):
@@ -63,7 +70,7 @@ class PrivateProxyDb(ProxyDbBase):
         """
         source = self.db.get_source_from_handle(handle)
         if source and not source.get_privacy():
-            return sanitize_source(self.db,source)
+            return sanitize_source(self.db, source)
         return None
 
     def get_object_from_handle(self, handle):
@@ -73,7 +80,7 @@ class PrivateProxyDb(ProxyDbBase):
         """
         media = self.db.get_object_from_handle(handle)
         if media and not media.get_privacy():
-            return sanitize_media(self.db,media)
+            return sanitize_media(self.db, media)
         return None
 
     def get_place_from_handle(self, handle):
@@ -83,7 +90,7 @@ class PrivateProxyDb(ProxyDbBase):
         """
         place = self.db.get_place_from_handle(handle)
         if place and not place.get_privacy():
-            return sanitize_place(self.db,place)
+            return sanitize_place(self.db, place)
         return None
 
     def get_event_from_handle(self, handle):
@@ -93,7 +100,7 @@ class PrivateProxyDb(ProxyDbBase):
         """
         event = self.db.get_event_from_handle(handle)
         if event and not event.get_privacy():
-            return sanitize_event(self.db,event)
+            return sanitize_event(self.db, event)
         return None
 
     def get_family_from_handle(self, handle):
@@ -103,7 +110,7 @@ class PrivateProxyDb(ProxyDbBase):
         """
         family = self.db.get_family_from_handle(handle)
         if family and not family.get_privacy():
-            return sanitize_family(self.db,family)
+            return sanitize_family(self.db, family)
         return None
 
     def get_repository_from_handle(self, handle):
@@ -113,7 +120,7 @@ class PrivateProxyDb(ProxyDbBase):
         """
         repository = self.db.get_repository_from_handle(handle)
         if repository and not repository.get_privacy():
-            return sanitize_repository(self.db,repository)
+            return sanitize_repository(self.db, repository)
         return None
 
     def get_note_from_handle(self, handle):
@@ -132,8 +139,8 @@ class PrivateProxyDb(ProxyDbBase):
         If no such Person exists, None is returned.
         """
         person = self.db.get_person_from_gramps_id(val)
-        if not person.get_privacy():
-            return sanitize_person(self.db,person)
+        if person and not person.get_privacy():
+            return sanitize_person(self.db, person)
         return None
 
     def get_family_from_gramps_id(self, val):
@@ -142,8 +149,8 @@ class PrivateProxyDb(ProxyDbBase):
         If no such Family exists, None is returned.
         """
         family = self.db.get_family_from_gramps_id(val)
-        if not family.get_privacy():
-            return sanitize_family(self.db,family)
+        if family and not family.get_privacy():
+            return sanitize_family(self.db, family)
         return None
 
     def get_event_from_gramps_id(self, val):
@@ -152,8 +159,8 @@ class PrivateProxyDb(ProxyDbBase):
         If no such Event exists, None is returned.
         """
         event = self.db.get_event_from_gramps_id(val)
-        if not event.get_privacy():
-            return sanitize_event(self.db,event)
+        if event and not event.get_privacy():
+            return sanitize_event(self.db, event)
         return None
 
     def get_place_from_gramps_id(self, val):
@@ -162,8 +169,8 @@ class PrivateProxyDb(ProxyDbBase):
         If no such Place exists, None is returned.
         """
         place = self.db.get_place_from_gramps_id(val)
-        if not place.get_privacy():
-            return sanitize_place(self.db,place)
+        if place and not place.get_privacy():
+            return sanitize_place(self.db, place)
         return None
 
     def get_source_from_gramps_id(self, val):
@@ -173,7 +180,7 @@ class PrivateProxyDb(ProxyDbBase):
         """
         source = self.db.get_source_from_gramps_id(val)
         if not source.get_privacy():
-            return sanitize_source(self.db,source)
+            return sanitize_source(self.db, source)
         return None
 
     def get_object_from_gramps_id(self, val):
@@ -181,9 +188,9 @@ class PrivateProxyDb(ProxyDbBase):
         Finds a MediaObject in the database from the passed gramps' ID.
         If no such MediaObject exists, None is returned.
         """
-        object = self.db.get_object_from_gramps_id(val)
-        if not object.get_privacy():
-            return sanitize_media(self.db, object)
+        obj = self.db.get_object_from_gramps_id(val)
+        if obj and not obj.get_privacy():
+            return sanitize_media(self.db, obj)
         return None
 
     def get_repository_from_gramps_id(self, val):
@@ -192,8 +199,8 @@ class PrivateProxyDb(ProxyDbBase):
         If no such Repository exists, None is returned.
         """
         repository = self.db.get_repository_from_gramps_id(val)
-        if not repository.get_privacy():
-            return sanitize_repository(self.db,repository)
+        if repository and not repository.get_privacy():
+            return sanitize_repository(self.db, repository)
         return None
 
     def get_note_from_gramps_id(self, val):
@@ -202,118 +209,73 @@ class PrivateProxyDb(ProxyDbBase):
         If no such Note exists, None is returned.
         """
         note = self.db.get_note_from_gramps_id(val)
-        if not note.get_privacy():
+        if note and not note.get_privacy():
             return note
         return None
 
-    def get_person_handles(self, sort_handles=True):
+    # Define predicate functions for use by default iterator methods
+    
+    def include_person(self, handle):
         """
-        Return a list of database handles, one handle for each Person in
-        the database. If sort_handles is True, the list is sorted by surnames
+        Predicate returning True if object is to be included, else False
         """
-        handles = []
-        for handle in self.db.get_person_handles(sort_handles):
-            person = self.db.get_person_from_handle(handle)
-            if not person.get_privacy():
-                handles.append(handle)
-        return handles
-
-    def get_place_handles(self, sort_handles=True):
+        obj = self.get_unfiltered_person(handle)
+        return obj and not obj.get_privacy()
+    
+    def include_family(self, handle):
         """
-        Return a list of database handles, one handle for each Place in
-        the database. If sort_handles is True, the list is sorted by
-        Place title.
+        Predicate returning True if object is to be included, else False
+        """        
+        obj = self.get_unfiltered_family(handle)
+        return obj and not obj.get_privacy()
+    
+    def include_event(self, handle):
         """
-        handles = []
-        for handle in self.db.get_place_handles(sort_handles):
-            place = self.db.get_place_from_handle(handle)
-            if not place.get_privacy():
-                handles.append(handle)
-        return handles
-
-    def get_source_handles(self, sort_handles=True):
+        Predicate returning True if object is to be included, else False
+        """        
+        obj = self.get_unfiltered_event(handle)
+        return obj and not obj.get_privacy()
+    
+    def include_source(self, handle):
         """
-        Return a list of database handles, one handle for each Source in
-        the database. If sort_handles is True, the list is sorted by
-        Source title.
+        Predicate returning True if object is to be included, else False
+        """        
+        obj = self.get_unfiltered_source(handle)
+        return obj and not obj.get_privacy()
+    
+    def include_place(self, handle):
         """
-        handles = []
-        for handle in self.db.get_source_handles(sort_handles):
-            source = self.db.get_source_from_handle(handle)
-            if not source.get_privacy():
-                handles.append(handle)
-        return handles
-
-    def get_media_object_handles(self, sort_handles=True):
+        Predicate returning True if object is to be included, else False
+        """        
+        obj = self.get_unfiltered_place(handle)
+        return obj and not obj.get_privacy()
+    
+    def include_media_object(self, handle):
         """
-        Return a list of database handles, one handle for each MediaObject in
-        the database. If sort_handles is True, the list is sorted by title.
+        Predicate returning True if object is to be included, else False
         """
-        handles = []
-        for handle in self.db.get_media_object_handles(sort_handles):
-            object = self.db.get_object_from_handle(handle)
-            if not object.get_privacy():
-                handles.append(handle)
-        return handles
-
-    def get_event_handles(self):
+        obj = self.get_unfiltered_object(handle)
+        return obj and not obj.get_privacy()
+    
+    def include_repository(self, handle):
         """
-        Return a list of database handles, one handle for each Event in
-        the database. 
+        Predicate returning True if object is to be included, else False
+        """        
+        obj = self.get_unfiltered_repository(handle)
+        return obj and not obj.get_privacy()
+    
+    def include_note(self, handle):
         """
-        handles = []
-        for handle in self.db.get_event_handles():
-            event = self.db.get_event_from_handle(handle)
-            if not event.get_privacy():
-                handles.append(handle)
-        return handles
-
-    def get_family_handles(self):
-        """
-        Return a list of database handles, one handle for each Family in
-        the database.
-        """
-        handles = []
-        for handle in self.db.get_family_handles():
-            family = self.db.get_family_from_handle(handle)
-            if not family.get_privacy():
-                handles.append(handle)
-        return handles
-
-    def get_repository_handles(self):
-        """
-        Return a list of database handles, one handle for each Repository in
-        the database.
-        """
-        handles = []
-        for handle in self.db.get_repository_handles():
-            repository = self.db.get_repository_from_handle(handle)
-            if not repository.get_privacy():
-                handles.append(handle)
-        return handles
-
-    def get_note_handles(self):
-        """
-        Return a list of database handles, one handle for each Note in
-        the database.
-        """
-        handles = []
-        for handle in self.db.get_note_handles():
-            note = self.db.get_note_from_handle(handle)
-            if not note.get_privacy():
-                handles.append(handle)
-        return handles
-
-    def get_researcher(self):
-        """returns the Researcher instance, providing information about
-        the owner of the database"""
-        return self.db.get_researcher()
+        Predicate returning True if object is to be included, else False
+        """        
+        obj = self.get_unfiltered_note(handle)
+        return obj and not obj.get_privacy()
 
     def get_default_person(self):
         """returns the default Person of the database"""
         person = self.db.get_default_person()
         if person and not person.get_privacy():
-            return sanitize_person(self.db,person)
+            return sanitize_person(self.db, person)
         return None
 
     def get_default_handle(self):
@@ -328,86 +290,78 @@ class PrivateProxyDb(ProxyDbBase):
         """
         returns True if the handle exists in the current Person database.
         """
-        has_person = False
-        person = self.db.get_person_from_handle()
+        person = self.db.get_person_from_handle(handle)
         if person and not person.get_privacy():
-                has_person = True
-        return has_person         
+            return True
+        return False
 
     def has_event_handle(self, handle):
         """
         returns True if the handle exists in the current Event database.
         """
-        has_event = False
-        event = self.db.get_event_from_handle()
+        event = self.db.get_event_from_handle(handle)
         if event and not event.get_privacy():
-                has_event = True
-        return has_event
+            return True
+        return False
 
     def has_source_handle(self, handle):
         """
         returns True if the handle exists in the current Source database.
         """
-        has_source = False
-        source = self.db.get_source_from_handle()
+        source = self.db.get_source_from_handle(handle)
         if source and not source.get_privacy():
-                has_source = True
-        return has_source 
+            return True
+        return False
 
     def has_place_handle(self, handle):
         """
         returns True if the handle exists in the current Place database.
         """
-        has_place = False
-        place = self.db.get_place_from_handle()
+        place = self.db.get_place_from_handle(handle)
         if place and not place.get_privacy():
-                has_place = True
-        return has_place
+            return True
+        return False
 
     def has_family_handle(self, handle):            
         """
-        returns True if the handle exists in the current Family database.
+        Return True if the handle exists in the current Family database.
         """
-        has_family = False
-        family = self.db.get_family_from_handle()
+        family = self.db.get_family_from_handle(handle)
         if family and not family.get_privacy():
-                has_family = True
-        return has_family
+            return True
+        return False
 
     def has_object_handle(self, handle):
         """
-        returns True if the handle exists in the current MediaObjectdatabase.
+        Return True if the handle exists in the current MediaObjectdatabase.
         """
-        has_object = False
-        object = self.db.get_object_from_handle()
+        object = self.db.get_object_from_handle(handle)
         if object and not object.get_privacy():
-                has_object = True
-        return has_object
+            return True
+        return False
 
     def has_repository_handle(self, handle):
         """
-        returns True if the handle exists in the current Repository database.
+        Return True if the handle exists in the current Repository database.
         """
-        has_repository = False
-        repository = self.db.get_repository_from_handle()
+        repository = self.db.get_repository_from_handle(handle)
         if repository and not repository.get_privacy():
-                has_repository = True
-        return has_repository
+            return True
+        return False
 
     def has_note_handle(self, handle):
         """
-        returns True if the handle exists in the current Note database.
+        Return True if the handle exists in the current Note database.
         """
-        has_note = False
-        note = self.db.get_note_from_handle()
+        note = self.db.get_note_from_handle(handle)
         if note and not note.get_privacy():
-                has_note = True
-        return has_note
+            return True
+        return False
 
     def find_backlink_handles(self, handle, include_classes=None):
         """
         Find all objects that hold a reference to the object handle.
-        Returns an interator over alist of (class_name, handle) tuples.
+        Returns an iterator over a list of (class_name, handle) tuples.
 
         @param handle: handle of the object to search for.
         @type handle: database handle
@@ -415,7 +369,7 @@ class PrivateProxyDb(ProxyDbBase):
                                 Default: None means include all classes.
         @type include_classes: list of class names
         
-        This default implementation does a sequencial scan through all
+        This default implementation does a sequential scan through all
         the primary object databases and is very slow. Backends can
         override this method to provide much faster implementations that
         make use of additional capabilities of the backend.
@@ -423,46 +377,41 @@ class PrivateProxyDb(ProxyDbBase):
         Note that this is a generator function, it returns a iterator for
         use in loops. If you want a list of the results use:
 
-        >    result_list = [i for i in find_backlink_handles(handle)]
+        >    result_list = list(find_backlink_handles(handle))
         """
         
         # This isn't done yet because it doesn't check if references are
         # private (like a SourceRef or MediaRef). It only checks if the 
         # referenced object is private.
 
+        objects = {
+            'Person'        : self.db.get_person_from_handle,
+            'Family'        : self.db.get_family_from_handle,
+            'Event'         : self.db.get_event_from_handle,
+            'Source'        : self.db.get_source_from_handle,
+            'Place'         : self.db.get_place_from_handle,
+            'MediaObject'   : self.db.get_object_from_handle,
+            'Note'          : self.db.get_note_from_handle,
+            'Repository'    : self.db.get_repository_from_handle,
+            }
+
         handle_itr = self.db.find_backlink_handles(handle, include_classes)
         for (class_name, handle) in handle_itr:
-            if class_name == 'Person':
-                obj = self.db.get_person_from_handle(handle)
-            elif class_name == 'Family':
-                obj = self.db.get_family_from_handle(handle)
-            elif class_name == 'Event':
-                obj = self.db.get_event_from_handle(handle)
-            elif class_name == 'Source':
-                obj = self.db.get_source_from_handle(handle)
-            elif class_name == 'Place':
-                obj = self.db.get_place_from_handle(handle)
-            elif class_name == 'MediaObject':
-                obj = self.db.get_object_from_handle(handle)
-            elif class_name == 'Note':
-                obj = self.db.get_note_from_handle(handle)
-            elif class_name == 'Repository':
-                obj = self.db.get_repository_from_handle(handle)
+            if class_name in objects:
+                obj = objects[class_name](handle)
+                if obj and not obj.get_privacy():
+                    yield (class_name, handle)
             else:
-                raise NotImplementedError
-            
-            if not obj.get_privacy():
-                yield (class_name, handle)
+                raise NotImplementedError                
         return
 
-
-def copy_media_ref_list(db, original_obj,clean_obj):
+def copy_media_ref_list(db, original_obj, clean_obj):
     """
     Copies media references from one object to another - excluding private 
     references and references to private objects.
 
     @param db: GRAMPS database to which the references belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param original_obj: Object that may have private references
     @type original_obj: MediaBase
     @param clean_obj: Object that will have only non-private references
@@ -476,13 +425,13 @@ def copy_media_ref_list(db, original_obj,clean_obj):
             if not media_object.get_privacy():
                 clean_obj.add_media_reference(sanitize_media_ref(db, media_ref))
 
-def copy_source_ref_list(db, original_obj,clean_obj):
+def copy_source_ref_list(db, original_obj, clean_obj):
     """
     Copies source references from one object to another - excluding private 
     references and references to private objects.
 
     @param db: GRAMPS database to which the references belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param original_obj: Object that may have private references
     @type original_obj: SourceBase
     @param clean_obj: Object that will have only non-private references
@@ -496,13 +445,13 @@ def copy_source_ref_list(db, original_obj,clean_obj):
             if not source.get_privacy():
                 clean_obj.add_source_reference(sanitize_source_ref(db, ref))
                 
-def copy_notes(db, original_obj,clean_obj):
+def copy_notes(db, original_obj, clean_obj):
     """
     Copies notes from one object to another - excluding references to private
     notes.
 
     @param db: GRAMPS database to which the references belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param original_obj: Object that may have private references
     @type original_obj: NoteBase
     @param clean_obj: Object that will have only non-private references
@@ -513,14 +462,35 @@ def copy_notes(db, original_obj,clean_obj):
         note = db.get_note_from_handle(note_handle)
         if not note.get_privacy():
             clean_obj.add_note(note_handle)
+
+def copy_associations(db, original_obj, clean_obj):
+    """
+    Copies associations from one object to another - excluding
+    references to private notes.
+
+    @param db: GRAMPS database to which the references belongs
+    @type db: DbBase
+    @param original_obj: Object that may have private references
+    @type original_obj: Base
+    @param clean_obj: Object that will have only non-private references
+    @type original_obj: Base
+    @returns: Nothing
+    """
+    new_person_ref_list = []
+    for person_ref in original_obj.get_person_ref_list():
+        if not person_ref.get_privacy():
+            associated_person = db.get_person_from_handle(person_ref.ref)
+            if associated_person and not associated_person.get_privacy():
+                new_person_ref_list.append(person_ref)
+    clean_obj.set_person_ref_list(new_person_ref_list)
             
-def copy_attributes(db, original_obj,clean_obj):
+def copy_attributes(db, original_obj, clean_obj):
     """
     Copies attributes from one object to another - excluding references to 
     private attributes.
 
     @param db: GRAMPS database to which the references belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param original_obj: Object that may have private references
     @type original_obj: AttributeBase
     @param clean_obj: Object that will have only non-private references
@@ -532,17 +502,17 @@ def copy_attributes(db, original_obj,clean_obj):
             new_attribute = Attribute()
             new_attribute.set_type(attribute.get_type())
             new_attribute.set_value(attribute.get_value())
-            copy_notes(db,attribute, new_attribute)
-            copy_source_ref_list(db,attribute, new_attribute)
+            copy_notes(db, attribute, new_attribute)
+            copy_source_ref_list(db, attribute, new_attribute)
             clean_obj.add_attribute(new_attribute)
       
-def copy_urls(db, original_obj,clean_obj):
+def copy_urls(db, original_obj, clean_obj):
     """
     Copies urls from one object to another - excluding references to 
     private urls.
 
     @param db: GRAMPS database to which the references belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param original_obj: Object that may have urls
     @type original_obj: UrlBase
     @param clean_obj: Object that will have only non-private urls
@@ -553,13 +523,13 @@ def copy_urls(db, original_obj,clean_obj):
         if not url.get_privacy():
             clean_obj.add_url(url)
             
-def copy_lds_ords(db, original_obj,clean_obj):
+def copy_lds_ords(db, original_obj, clean_obj):
     """
     Copies LDS ORDs from one object to another - excluding references to 
     private LDS ORDs.
 
     @param db: GRAMPS database to which the references belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param original_obj: Object that may have LDS ORDs
     @type original_obj: LdsOrdBase
     @param clean_obj: Object that will have only non-private LDS ORDs
@@ -570,13 +540,13 @@ def copy_lds_ords(db, original_obj,clean_obj):
         if not lds_ord.get_privacy():
             clean_obj.add_lds_ord(sanitize_lds_ord(db, lds_ord))
            
-def copy_addresses(db, original_obj,clean_obj):
+def copy_addresses(db, original_obj, clean_obj):
     """
     Copies addresses from one object to another - excluding references to 
     private addresses.
 
     @param db: GRAMPS database to which the references belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param original_obj: Object that may have addresses
     @type original_obj: AddressBase
     @param clean_obj: Object that will have only non-private addresses
@@ -594,7 +564,7 @@ def sanitize_lds_ord(db, lds_ord):
     removed from it.
     
     @param db: GRAMPS database to which the LdsOrd object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param name: source LdsOrd object that will be copied with
     privacy records removed
     @type name: LdsOrd
@@ -630,7 +600,7 @@ def sanitize_address(db, address):
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param name: source Address object that will be copied with
     privacy records removed
     @type name: Address
@@ -660,7 +630,7 @@ def sanitize_name(db, name):
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param name: source Name object that will be copied with
     privacy records removed
     @type name: Name
@@ -693,7 +663,7 @@ def sanitize_media_ref(db, media_ref):
     removed from it.
     
     @param db: GRAMPS database to which the MediaRef object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param source_ref: source MediaRef object that will be copied with
     privacy records removed
     @type source_ref: MediaRef
@@ -717,7 +687,7 @@ def sanitize_source_ref(db, source_ref):
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param source_ref: source SourceRef object that will be copied with
     privacy records removed
     @type source_ref: SourceRef
@@ -740,7 +710,7 @@ def sanitize_event_ref(db, event_ref):
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param event_ref: source EventRef object that will be copied with
     privacy records removed
     @type event_ref: EventRef
@@ -751,19 +721,19 @@ def sanitize_event_ref(db, event_ref):
     
     new_ref.set_reference_handle(event_ref.get_reference_handle())
     new_ref.set_role(event_ref.get_role())
-    copy_notes(db,event_ref, new_ref)
-    copy_attributes(db,event_ref, new_ref)
+    copy_notes(db, event_ref, new_ref)
+    copy_attributes(db, event_ref, new_ref)
     
     return new_ref
 
-def sanitize_person(db,person):
+def sanitize_person(db, person):
     """
     Create a new Person instance based off the passed Person
     instance. The returned instance has all private records
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param person: source Person object that will be copied with
     privacy records removed
     @type person: Person
@@ -817,42 +787,43 @@ def sanitize_person(db,person):
     for event_ref in person.get_event_ref_list():
         if event_ref and not event_ref.get_privacy():
             event = db.get_event_from_handle(event_ref.ref)
-            if not event.get_privacy():
-                new_person.add_event_ref(sanitize_event_ref(db,event_ref))
+            if event and not event.get_privacy():
+                new_person.add_event_ref(sanitize_event_ref(db, event_ref))
 
     # Copy birth and death after event list to maintain the order.
     # copy birth event
     event_ref = person.get_birth_ref()
     if event_ref and not event_ref.get_privacy():
         event = db.get_event_from_handle(event_ref.ref)
-        if not event.get_privacy():
-            new_person.set_birth_ref(sanitize_event_ref(db,event_ref))
+        if event and not event.get_privacy():
+            new_person.set_birth_ref(sanitize_event_ref(db, event_ref))
 
     # copy death event
     event_ref = person.get_death_ref()
     if event_ref and not event_ref.get_privacy():
         event = db.get_event_from_handle(event_ref.ref)
-        if not event.get_privacy():
-            new_person.set_death_ref(sanitize_event_ref(db,event_ref))
+        if event and not event.get_privacy():
+            new_person.set_death_ref(sanitize_event_ref(db, event_ref))
 
-    copy_addresses(db,person, new_person)
-    copy_attributes(db,person, new_person)
-    copy_source_ref_list(db,person, new_person)
-    copy_urls(db,person, new_person)
-    copy_media_ref_list(db,person, new_person)
-    copy_lds_ords(db,person, new_person)
-    copy_notes(db,person, new_person)
+    copy_addresses(db, person, new_person)
+    copy_attributes(db, person, new_person)
+    copy_source_ref_list(db, person, new_person)
+    copy_urls(db, person, new_person)
+    copy_media_ref_list(db, person, new_person)
+    copy_lds_ords(db, person, new_person)
+    copy_notes(db, person, new_person)
+    copy_associations(db, person, new_person)
     
     return new_person
 
-def sanitize_source(db,source):
+def sanitize_source(db, source):
     """
     Create a new Source instance based off the passed Source
     instance. The returned instance has all private records
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param source: source Source object that will be copied with
     privacy records removed
     @type source: Source
@@ -878,19 +849,19 @@ def sanitize_source(db,source):
             if not repo.get_privacy():
                 new_source.add_repo_reference(RepoRef(repo_ref))
 
-    copy_media_ref_list(db,source, new_source)
-    copy_notes(db,source, new_source)
+    copy_media_ref_list(db, source, new_source)
+    copy_notes(db, source, new_source)
     
     return new_source
 
-def sanitize_media(db,media):
+def sanitize_media(db, media):
     """
     Create a new MediaObject instance based off the passed Media
     instance. The returned instance has all private records
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param media: source Media object that will be copied with
     privacy records removed
     @type media: MediaObject
@@ -908,20 +879,20 @@ def sanitize_media(db,media):
     new_media.set_date_object(media.get_date_object())
     new_media.set_marker(media.get_marker())
 
-    copy_source_ref_list(db,media, new_media)
-    copy_attributes(db,media, new_media)
-    copy_notes(db,media, new_media)
+    copy_source_ref_list(db, media, new_media)
+    copy_attributes(db, media, new_media)
+    copy_notes(db, media, new_media)
     
     return new_media
 
-def sanitize_place(db,place):
+def sanitize_place(db, place):
     """
     Create a new Place instance based off the passed Place
     instance. The returned instance has all private records
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param place: source Place object that will be copied with
     privacy records removed
     @type place: Place
@@ -940,21 +911,21 @@ def sanitize_place(db,place):
     new_place.set_alternate_locations(place.get_alternate_locations())
     new_place.set_marker(place.get_marker())
 
-    copy_source_ref_list(db,place, new_place)
-    copy_notes(db,place, new_place)
-    copy_media_ref_list(db,place, new_place)
-    copy_urls(db,place, new_place)
+    copy_source_ref_list(db, place, new_place)
+    copy_notes(db, place, new_place)
+    copy_media_ref_list(db, place, new_place)
+    copy_urls(db, place, new_place)
     
     return new_place
 
-def sanitize_event(db,event):
+def sanitize_event(db, event):
     """
     Create a new Event instance based off the passed Event
     instance. The returned instance has all private records
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param event: source Event object that will be copied with
     privacy records removed
     @type event: Event
@@ -971,10 +942,10 @@ def sanitize_event(db,event):
     new_event.set_marker(event.get_marker())
     new_event.set_change_time(event.get_change_time())
 
-    copy_source_ref_list(db,event, new_event)
-    copy_notes(db,event, new_event)
-    copy_media_ref_list(db,event, new_event)
-    copy_attributes(db,event, new_event)
+    copy_source_ref_list(db, event, new_event)
+    copy_notes(db, event, new_event)
+    copy_media_ref_list(db, event, new_event)
+    copy_attributes(db, event, new_event)
     
     place_handle = event.get_place_handle()
     place = db.get_place_from_handle(place_handle)
@@ -983,14 +954,14 @@ def sanitize_event(db,event):
     
     return new_event
             
-def sanitize_family(db,family):
+def sanitize_family(db, family):
     """
     Create a new Family instance based off the passed Family
     instance. The returned instance has all private records
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
+    @type db: DbBase
     @param family: source Family object that will be copied with
     privacy records removed
     @type family: Family
@@ -1016,7 +987,7 @@ def sanitize_family(db,family):
     mother_handle = family.get_mother_handle()
     if mother_handle:
         mother = db.get_person_from_handle(mother_handle)
-        if not mother.get_privacy():
+        if mother and not mother.get_privacy():
             new_family.set_mother_handle(mother_handle)
         
     # Copy child references.
@@ -1032,34 +1003,34 @@ def sanitize_family(db,family):
         new_ref.set_reference_handle(child_ref.get_reference_handle())
         new_ref.set_father_relation(child_ref.get_father_relation())
         new_ref.set_mother_relation(child_ref.get_mother_relation())
-        copy_notes(db,child_ref, new_ref)
-        copy_source_ref_list(db,child_ref, new_ref)
+        copy_notes(db, child_ref, new_ref)
+        copy_source_ref_list(db, child_ref, new_ref)
         new_family.add_child_ref(new_ref)
         
     # Copy event ref list.
     for event_ref in family.get_event_ref_list():
         if event_ref and not event_ref.get_privacy():
             event = db.get_event_from_handle(event_ref.ref)
-            if not event.get_privacy():
-                new_family.add_event_ref(sanitize_event_ref(db,event_ref))
+            if event and not event.get_privacy():
+                new_family.add_event_ref(sanitize_event_ref(db, event_ref))
 
-    copy_source_ref_list(db,family, new_family)
-    copy_notes(db,family, new_family)
-    copy_media_ref_list(db,family, new_family)
-    copy_attributes(db,family, new_family)
-    copy_lds_ords(db,family, new_family)
+    copy_source_ref_list(db, family, new_family)
+    copy_notes(db, family, new_family)
+    copy_media_ref_list(db, family, new_family)
+    copy_attributes(db, family, new_family)
+    copy_lds_ords(db, family, new_family)
     
     return new_family
 
-def sanitize_repository(db,repository):
+def sanitize_repository(db, repository):
     """
     Create a new Repository instance based off the passed Repository
     instance. The returned instance has all private records
     removed from it.
     
     @param db: GRAMPS database to which the Person object belongs
-    @type db: GrampsDbBase
-    @param repository: source Repsitory object that will be copied with
+    @type db: DbBase
+    @param repository: source Repository object that will be copied with
     privacy records removed
     @type repository: Repository
     @returns: 'cleansed' Repository object
@@ -1074,8 +1045,8 @@ def sanitize_repository(db,repository):
     new_repository.set_change_time(repository.get_change_time())
     new_repository.set_marker(repository.get_marker())
 
-    copy_notes(db,repository, new_repository)
-    copy_addresses(db,repository, new_repository)
-    copy_urls(db,repository, new_repository)
+    copy_notes(db, repository, new_repository)
+    copy_addresses(db, repository, new_repository)
+    copy_urls(db, repository, new_repository)
     
     return new_repository
