@@ -18,8 +18,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-from dbutils import *
-from progressmon import ProgressMonitor
-from longop import LongOpStatus
-from callback import Callback
+"""
+Generic utilities useful for users of the gen package
+"""
 
+from fallback import *
+from configmanager import ConfigManager
+from callback import Callback
