@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: AncestorTree.py 12842 2009-07-28 04:28:12Z pez4brian $
+# $Id: AncestorTree.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 """Reports/Graphical Reports/Ancestor Tree"""
 
@@ -29,18 +29,19 @@
 #
 #------------------------------------------------------------------------
 import math
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import BaseDoc
-from SubstKeywords import SubstKeywords
-from gen.plug import PluginManager
+from gen.display.name import displayer as name_displayer
+from Errors import ReportError
+from gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
+                            FONT_SANS_SERIF, PARA_ALIGN_CENTER)
 from gen.plug.menu import BooleanOption, NumberOption, TextOption, PersonOption
-from ReportBase import Report, ReportUtils, CATEGORY_DRAW, MenuReportOptions
-from BasicUtils import name_displayer
+from ReportBase import Report, ReportUtils, MenuReportOptions
+from SubstKeywords import SubstKeywords
 
 pt2cm = ReportUtils.pt2cm
 
@@ -123,18 +124,16 @@ class GenChart(object):
         self.array[y][x] = value
 
     def dimensions(self):
-        return (max(self.array.keys())+1, self.max_x+1)
+        return (max(self.array)+1, self.max_x+1)
 
     def compress(self):
         new_map = {}
         new_array = {}
         old_y = 0
         new_y = 0
-
-        for key in self.array.keys():
-            i = self.array[key]
+        for key, i in self.array.iteritems():
             old_y = key
-            if self.not_blank(i.values()):
+            if self.not_blank(i.itervalues()):
                 self.compress_map[old_y] = new_y
                 new_array[new_y] = i
                 x = 0
@@ -190,6 +189,8 @@ class AncestorTree(Report):
         
         pid = menu.get_option_by_name('pid').get_value()
         center_person = database.get_person_from_gramps_id(pid)
+        if (center_person == None) :
+            raise ReportError(_("Person %s is not in the Database") % pid )
         
         name = name_displayer.display_formal(center_person)
         self.title = _("Ancestor Graph for %s") % name
@@ -203,14 +204,12 @@ class AncestorTree(Report):
         self.scale = 1
 
         self.apply_filter(center_person.get_handle(), 1)
-
-        keys = self.map.keys()
-        keys.sort()
+        keys = sorted(self.map)
         max_key = log2(keys[-1])
 
         self.genchart = GenChart(max_key+1)
-        for key in self.map.keys():
-            self.genchart.set(key,self.map[key])
+        for key, chart in self.map.iteritems():
+            self.genchart.set(key, chart)
         self.calc()
         
         if self.force_fit:
@@ -316,11 +315,11 @@ class AncestorTree(Report):
 
             bw = calc_width / (uw/maxx)
             bh = self.box_height / (self.uh/maxy)
-            
+
             self.scale = max(bw ,bh)
-            self.box_width = self.box_width / self.scale
-            self.box_height = self.box_height / self.scale
-            self.box_pad_pts = self.box_pad_pts / self.scale
+            self.box_width /= self.scale
+            self.box_height /= self.scale
+            self.box_pad_pts /= self.scale
 
         maxh = int(self.uh / self.box_height)
         maxw = int(uw / calc_width) 
@@ -491,57 +490,36 @@ class AncestorTreeOptions(MenuReportOptions):
         """Make the default output style for the Ancestor Tree."""
         
         ## Paragraph Styles:
-        f = BaseDoc.FontStyle()
+        f = FontStyle()
         f.set_size(9)
-        f.set_type_face(BaseDoc.FONT_SANS_SERIF)
-        p = BaseDoc.ParagraphStyle()
+        f.set_type_face(FONT_SANS_SERIF)
+        p = ParagraphStyle()
         p.set_font(f)
         p.set_description(_('The basic style used for the text display.'))
         default_style.add_paragraph_style("AC2-Normal", p)
 
-        f = BaseDoc.FontStyle()
+        f = FontStyle()
         f.set_size(16)
-        f.set_type_face(BaseDoc.FONT_SANS_SERIF)
-        p = BaseDoc.ParagraphStyle()
+        f.set_type_face(FONT_SANS_SERIF)
+        p = ParagraphStyle()
         p.set_font(f)
-        p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
+        p.set_alignment(PARA_ALIGN_CENTER)
         p.set_description(_('The basic style used for the title display.'))
         default_style.add_paragraph_style("AC2-Title", p)
         
         ## Draw styles
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style("AC2-Normal")
         g.set_shadow(1, 0.2)
         g.set_fill_color((255, 255, 255))
         default_style.add_draw_style("AC2-box", g)
 
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style("AC2-Title")
         g.set_color((0, 0, 0))
         g.set_fill_color((255, 255, 255))
         g.set_line_width(0)
         default_style.add_draw_style("AC2-title", g)
 
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         default_style.add_draw_style("AC2-line", g)
-
-#------------------------------------------------------------------------
-#
-# 
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_report(
-    name = 'ancestor_chart',
-    category = CATEGORY_DRAW,
-    report_class = AncestorTree,
-    options_class = AncestorTreeOptions,
-    modes = PluginManager.REPORT_MODE_GUI | \
-            PluginManager.REPORT_MODE_BKI | \
-            PluginManager.REPORT_MODE_CLI,
-    translated_name = _("Ancestor Tree"),
-    status = _("Stable"),
-    author_name = "Donald N. Allingham",
-    author_email = "don@gramps-project.org",
-    description = _("Produces a graphical ancestral tree"),
-    )
