@@ -20,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: ExportGedcom.py 13291 2009-10-03 05:05:38Z dsblank $
+# $Id: ExportGedcom.py 15235 2010-04-19 13:49:49Z ldnp $
 
 "Export to GEDCOM"
 
@@ -29,7 +29,7 @@
 # Standard Python Modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 import os
 import time
 
@@ -40,14 +40,14 @@ import time
 #-------------------------------------------------------------------------
 import gen.lib
 import const
-import GrampsDbUtils._GedcomInfo as GedcomInfo
+import libgedcom
 import Errors
-import ExportOptions
-import BasicUtils
-from Utils import media_path_full
+from ExportOptions import WriterOptionBox
+from gen.updatecallback import UpdateCallback
+from Utils import media_path_full, get_unicode_path
 import gen.proxy
 from QuestionDialog import ErrorDialog
-from gen.plug import PluginManager, ExportPlugin
+from PlaceUtils import conv_lat_lon
 
 #-------------------------------------------------------------------------
 #
@@ -59,43 +59,6 @@ NEEDS_PARAMETER = set(
     ["CAST", "DSCR", "EDUC", "IDNO", "NATI", "NCHI", 
      "NMR",  "OCCU", "PROP", "RELI", "SSN",  "TITL"])
 
-#-------------------------------------------------------------------------
-#
-# Calendar month names
-#
-#-------------------------------------------------------------------------
- 
-HMONTH = [
-    "", "ELUL", "TSH", "CSH", "KSL", "TVT", "SHV", "ADR", 
-    "ADS", "NSN", "IYR", "SVN", "TMZ", "AAV", "ELL" ]
-
-FMONTH = [
-    "",     "VEND", "BRUM", "FRIM", "NIVO", "PLUV", "VENT", 
-    "GERM", "FLOR", "PRAI", "MESS", "THER", "FRUC", "COMP"]
-
-MONTH = [
-    "",    "JAN", "FEB", "MAR", "APR", "MAY", "JUN", 
-    "JUL", "AUG", "SEP", "OCT", "NOV", "DEC" ]
-
-CALENDAR_MAP = {
-    gen.lib.Date.CAL_HEBREW : (HMONTH, '@#DHEBREW@'), 
-    gen.lib.Date.CAL_FRENCH : (FMONTH, '@#DFRENCH R@'), 
-    gen.lib.Date.CAL_JULIAN : (MONTH, '@#DJULIAN@'), 
-    gen.lib.Date.CAL_SWEDISH : (MONTH, '@#DUNKNOWN@'), 
-    }
-
-DATE_MODIFIER = {
-    gen.lib.Date.MOD_ABOUT   : "ABT", 
-    gen.lib.Date.MOD_BEFORE  : "BEF", 
-    gen.lib.Date.MOD_AFTER   : "AFT", 
-    #RelLib.Date.MOD_INTERPRETED : "INT",
-    }
-
-DATE_QUALITY = {
-    gen.lib.Date.QUAL_CALCULATED : "CAL", 
-    gen.lib.Date.QUAL_ESTIMATED  : "EST", 
-}    
-
 LDS_ORD_NAME = {
     gen.lib.LdsOrd.BAPTISM         : 'BAPL', 
     gen.lib.LdsOrd.ENDOWMENT       : 'ENDL', 
@@ -159,7 +122,7 @@ QUALITY_MAP = {
 #-------------------------------------------------------------------------
 def sort_by_gramps_id(first, second):
     """
-    Sort objects by their GRAMPS ID.
+    Sort objects by their Gramps ID.
     """
     return cmp(first.gramps_id, second.gramps_id)
 
@@ -170,7 +133,7 @@ def sort_by_gramps_id(first, second):
 #-------------------------------------------------------------------------
 def sort_handles_by_id(handle_list, handle_to_object):
     """
-    Sort a list of handles by the GRAMPS ID. 
+    Sort a list of handles by the Gramps ID. 
     
     The function that returns the object from the handle needs to be supplied 
     so that we get the right object.
@@ -184,82 +147,6 @@ def sort_handles_by_id(handle_list, handle_to_object):
     sorted_list.sort()
     return sorted_list
 
-#-------------------------------------------------------------------------
-#
-# make_date
-#
-#-------------------------------------------------------------------------
-def make_date(subdate, calendar, mode, quality):
-    """
-    Convert a GRAMPS date structure into a GEDCOM compatible date.
-    """
-    retval = ""
-    (day, mon, year) = subdate[0:3]
-    
-    (mmap, prefix) = CALENDAR_MAP.get(calendar, (MONTH, ""))
-        
-    if year < 0:
-        year = -year
-        bce = " B.C."
-    else:
-        bce = ""
-
-    try:
-        retval = __build_date_string(day, mon, year, bce, mmap)
-    except IndexError:
-        print "Month index error - %d" % mon
-        retval = "%d%s" % (year, bce)
-    
-    if calendar == gen.lib.Date.CAL_SWEDISH:
-        # If Swedish calendar use ISO for for date and append (swedish)
-        # to indicate calandar
-        if year and not mon and not day:
-            retval = "%i" % (year)
-        else:
-            retval = "%i-%02i-%02i" % (year, mon, day)
-        retval = retval + " (swedish)"
-        # Skip prefix @#DUNKNOWN@ as it seems
-        # not used in all other genealogy applications.
-        # GRAMPS can handle it on import, but not with (swedish) appended
-        # to explain what calendar, the unknown refer to
-        prefix = ""
-    
-    if prefix:
-        retval = "%s %s" % (prefix, retval)
-
-    if mode in DATE_MODIFIER:
-        retval = "%s %s" % (DATE_MODIFIER[mode], retval)
-
-    if quality in DATE_QUALITY:
-        retval = "%s %s" % (DATE_QUALITY[quality], retval)
-
-    return retval
-
-#-------------------------------------------------------------------------
-#
-# __build_date_string
-#
-#-------------------------------------------------------------------------
-def __build_date_string(day, mon, year, bce, mmap):
-    """
-    Build a date string from the supplied information.
-    """
-    if day == 0:
-        if mon == 0:
-            retval = '%d%s' % (year, bce)
-        elif year == 0:
-            retval = '(%s)' % mmap[mon]
-        else:
-            retval = "%s %d%s" % (mmap[mon], year, bce)
-    elif mon == 0:
-        retval = '%d%s' % (year, bce)
-    elif year == 0:
-        retval = "(%d %s)" % (day, mmap[mon])
-    else:
-        retval = "%d %s %d%s" % (day, mmap[mon], year, bce)
-    return retval
-    
-
 #-------------------------------------------------------------------------
 #
 # breakup
@@ -315,16 +202,16 @@ def event_has_subordinate_data(event, event_ref):
 # GedcomWriter class
 #
 #-------------------------------------------------------------------------
-class GedcomWriter(BasicUtils.UpdateCallback):
+class GedcomWriter(UpdateCallback):
     """
     The GEDCOM writer creates a GEDCOM file that contains the exported 
-    information from the database. It derives from BasicUtils.UpdateCallback
+    information from the database. It derives from UpdateCallback
     so that it can provide visual feedback via a progress bar if needed.
     """
 
     def __init__(self, database, cmd_line=0,
                  option_box=None, callback=None):
-        BasicUtils.UpdateCallback.__init__(self, callback)
+        UpdateCallback.__init__(self, callback)
 
         self.dbase = database
         self.cmd_line = cmd_line
@@ -408,12 +295,11 @@ class GedcomWriter(BasicUtils.UpdateCallback):
 
     def write_gedcom_file(self, filename):
         """
-        Write the actual GEDCOM file to the specfied filename.
+        Write the actual GEDCOM file to the specified filename.
         """
 
         self.dirname = os.path.dirname (filename)
         self.gedcom_file = open(filename, "w")
-
         self.__header(filename)
         self.__submitter()
         self.__individuals()
@@ -443,6 +329,8 @@ class GedcomWriter(BasicUtils.UpdateCallback):
             textlist = textlines.split('\n')
             token_level = level
             for text in textlist:
+                # make it unicode so that breakup below does the right thin.
+                text = get_unicode_path(text)
                 if limit:
                     prefix = "\n%d CONC " % (level + 1)
                     txt = prefix.join(breakup(text, limit))
@@ -489,14 +377,14 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         """
         local_time = time.localtime(time.time())
         (year, mon, day, hour, minutes, sec) = local_time[0:6]
-        date_str = "%d %s %d" % (day, MONTH[mon], year)
+        date_str = "%d %s %d" % (day, libgedcom.MONTH[mon], year)
         time_str = "%02d:%02d:%02d" % (hour, minutes, sec)
         rname = self.dbase.get_researcher().get_name()
 
         self.__writeln(0, "HEAD")
-        self.__writeln(1, "SOUR", "GRAMPS")
+        self.__writeln(1, "SOUR", "Gramps")
         self.__writeln(2, "VERS",  const.VERSION)
-        self.__writeln(2, "NAME", "GRAMPS")
+        self.__writeln(2, "NAME", "Gramps")
         self.__writeln(1, "DATE", date_str)
         self.__writeln(2, "TIME", time_str)
         self.__writeln(1, "SUBM", "@SUBM@")
@@ -574,8 +462,8 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         self.reset(_("Writing individuals"))
         self.progress_cnt += 1
         self.update(self.progress_cnt)
-        phandles = self.dbase.get_person_handles()
-
+        phandles = self.dbase.iter_person_handles()
+        
         sorted_list = []
         for handle in phandles:
             person = self.dbase.get_person_from_handle(handle)
@@ -651,7 +539,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         """
         Write out the list of note handles to the current level. 
         
-        We use the GRAMPS ID as the XREF for the GEDCOM file.
+        We use the Gramps ID as the XREF for the GEDCOM file.
 
         """
         for note_handle in notelist:
@@ -721,7 +609,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
             if etype in (gen.lib.EventType.BIRTH, gen.lib.EventType.DEATH):
                 continue
                 
-            val = GedcomInfo.personalConstantEvents.get(etype, "").strip()
+            val = libgedcom.personalConstantEvents.get(etype, "").strip()
                         
             if val and val.strip():
                 if val in NEEDS_PARAMETER:
@@ -799,7 +687,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         for attr in attr_list:
 
             attr_type = int(attr.get_type())
-            name = GedcomInfo.personalConstantAttributes.get(attr_type)
+            name = libgedcom.personalConstantAttributes.get(attr_type)
             key = str(attr.get_type())
             value = attr.get_value().strip().replace('\r', ' ')
             
@@ -861,7 +749,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
 
     def __child_families(self, person):
         """
-        Write the GRAMPS ID as the XREF for each family in which the person
+        Write the Gramps ID as the XREF for each family in which the person
         is listed as a child.
         """
         
@@ -874,7 +762,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
 
     def __parent_families(self, person):
         """
-        Write the GRAMPS ID as the XREF for each family in which the person
+        Write the Gramps ID as the XREF for each family in which the person
         is listed as a parent.
         """
 
@@ -911,7 +799,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
 
     def __families(self):
         """
-        Write out the list of families, sorting by GRAMPS ID.
+        Write out the list of families, sorting by Gramps ID.
         """
         self.reset(_("Writing families"))
         self.progress_cnt += 1
@@ -971,7 +859,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         """
         Write the family reference to the file. 
         
-        This is either 'WIFE' or 'HUSB'. As usual, we use the GRAMPS ID as the 
+        This is either 'WIFE' or 'HUSB'. As usual, we use the Gramps ID as the 
         XREF value.
         
         """
@@ -987,10 +875,10 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         event to discover the event type.
         
         """
-        for event_ref in [ ref for ref in family.get_event_ref_list()]:
+        for event_ref in family.get_event_ref_list():
             event = self.dbase.get_event_from_handle(event_ref.ref)
             etype = int(event.get_type())
-            val = GedcomInfo.familyConstantEvents.get(etype)
+            val = libgedcom.familyConstantEvents.get(etype)
             
             if val:
                 if event_has_subordinate_data(event, event_ref):
@@ -1016,7 +904,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
 
     def __family_event_attrs(self, attr_list, level):
         """
-        Write the attributes assocated with the family event. 
+        Write the attributes associated with the family event. 
         
         The only ones we really care about are FATHER_AGE and MOTHER_AGE which 
         we translate to WIFE/HUSB AGE attributes.
@@ -1045,7 +933,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         for attr in attr_list:
             
             attr_type = int(attr.get_type())
-            name = GedcomInfo.familyConstantAttributes.get(attr_type)
+            name = libgedcom.familyConstantAttributes.get(attr_type)
             value = attr.get_value().replace('\r', ' ')
 
             if attr_type in ("AFN", "RFN", "REFN", "_UID"):
@@ -1065,7 +953,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
 
     def __sources(self):
         """
-        Write out the list of sources, sorting by GRAMPS ID.
+        Write out the list of sources, sorting by Gramps ID.
         """
         self.reset(_("Writing sources"))
         self.progress_cnt += 1
@@ -1099,7 +987,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
 
     def __notes(self):
         """
-        Write out the list of notes, sorting by GRAMPS ID.
+        Write out the list of notes, sorting by Gramps ID.
         """
         self.reset(_("Writing notes"))
         self.progress_cnt += 1
@@ -1126,7 +1014,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
 
     def __repos(self):
         """
-        Write out the list of repositories, sorting by GRAMPS ID.
+        Write out the list of repositories, sorting by Gramps ID.
 
         REPOSITORY_RECORD:=
         n @<XREF:REPO>@ REPO {1:1}
@@ -1213,7 +1101,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         self.__writeln(level, 'CHAN')
         time_val = time.localtime(timeval)
         self.__writeln(level+1, 'DATE', '%d %s %d' % (
-                time_val[2], MONTH[time_val[1]], time_val[0]))
+                time_val[2], libgedcom.MONTH[time_val[1]], time_val[0]))
         self.__writeln(level+2, 'TIME', '%02d:%02d:%02d' % (
                 time_val[3], time_val[4], time_val[5]))
 
@@ -1313,7 +1201,7 @@ class GedcomWriter(BasicUtils.UpdateCallback):
     def __date(self, level, date):
         """
         Write the 'DATE' GEDCOM token, along with the date in GEDCOM's
-        expected formta.
+        expected format.
         """
         start = date.get_start_date()
         if start != gen.lib.Date.EMPTY:
@@ -1322,14 +1210,16 @@ class GedcomWriter(BasicUtils.UpdateCallback):
             quality = date.get_quality()
             if mod == gen.lib.Date.MOD_SPAN:
                 val = "FROM %s TO %s" % (
-                    make_date(start, cal, mod, quality), 
-                    make_date(date.get_stop_date(), cal, mod, quality))
+                    libgedcom.make_gedcom_date(start, cal, mod, quality), 
+                    libgedcom.make_gedcom_date(date.get_stop_date(), 
+                                               cal, mod, quality))
             elif mod == gen.lib.Date.MOD_RANGE:
                 val = "BET %s AND %s" % (
-                    make_date(start, cal, mod, quality), 
-                    make_date(date.get_stop_date(), cal, mod, quality))
+                    libgedcom.make_gedcom_date(start, cal, mod, quality), 
+                    libgedcom.make_gedcom_date(date.get_stop_date(), 
+                                               cal, mod, quality))
             else:
-                val = make_date(start, cal, mod, quality)
+                val = libgedcom.make_gedcom_date(start, cal, mod, quality)
             self.__writeln(level, 'DATE', val)
         elif date.get_text():
             self.__writeln(level, 'DATE', date.get_text())
@@ -1346,27 +1236,18 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         +1 <<SOURCE_CITATION>> {0:M} 
         +1 <<NOTE_STRUCTURE>> {0:M} 
         """
+        gedcom_name = name.get_gedcom_name()
+
         firstname = name.get_first_name().strip()
         patron = name.get_patronymic().strip()
         if patron:
             firstname = "%s %s" % (firstname, patron)
-
         surname = name.get_surname().replace('/', '?')
         surprefix = name.get_surname_prefix().replace('/', '?')
         suffix = name.get_suffix()
         title = name.get_title()
-        if suffix == "":
-            if surprefix == "":
-                self.__writeln(1, 'NAME', '%s /%s/' % (firstname, surname))
-            else:
-                self.__writeln(1, 'NAME', '%s /%s %s/' % 
-                               (firstname, surprefix, surname))
-        elif surprefix == "":
-            self.__writeln(1, 'NAME', '%s /%s/ %s' % 
-                           (firstname, surname, suffix))
-        else:
-            self.__writeln(1, 'NAME', '%s /%s %s/ %s' % 
-                           (firstname, surprefix, surname, suffix))
+
+        self.__writeln(1, 'NAME', gedcom_name)
 
         if firstname:
             self.__writeln(2, 'GIVN', firstname)
@@ -1409,7 +1290,11 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         # Reference to the source
         self.__writeln(level, "SOUR", "@%s@" % src.get_gramps_id())
         if ref.get_page() != "":
-            self.__writeln(level+1, 'PAGE', ref.get_page())
+        # PAGE <WHERE_WITHIN_SOURCE> can not have CONC lines.
+        # WHERE_WITHIN_SOURCE:= {Size=1:248}
+        # Maximize line to 248 and set limit to 248, for no line split
+            self.__writeln(level+1, 'PAGE', ref.get_page()[0:248], limit=248)
+
 
         conf = min(ref.get_confidence_level(), gen.lib.SourceRef.CONF_VERY_HIGH)
         if conf != gen.lib.SourceRef.CONF_NORMAL and conf != -1:
@@ -1484,6 +1369,8 @@ class GedcomWriter(BasicUtils.UpdateCallback):
         self.__writeln(level, "PLAC", place_name.replace('\r', ' '))
         longitude = place.get_longitude()
         latitude = place.get_latitude()
+        if longitude and latitude:
+            (latitude, longitude) = conv_lat_lon(latitude, longitude, "GEDCOM")
         if longitude and latitude:
             self.__writeln(level+1, "MAP")
             self.__writeln(level+2, 'LATI', latitude)
@@ -1524,23 +1411,4 @@ def export_data(database, filename, option_box=None, callback=None):
         ErrorDialog(msg2, str(msg))
     except Errors.DatabaseError, msg:
         ErrorDialog(_("Export failed"), str(msg))
-    except:
-        ErrorDialog(_("Could not create %s") % filename)
     return ret
-
-#------------------------------------------------------------------------
-#
-# Register with the plugin system
-#
-#------------------------------------------------------------------------
-_description = _('GEDCOM is used to transfer data between genealogy programs. '
-                'Most genealogy software will accept a GEDCOM file as input.')
-_config = (_('GEDCOM export options'), ExportOptions.WriterOptionBox)
-
-pmgr = PluginManager.get_instance()
-plugin = ExportPlugin(name            = _('GE_DCOM'), 
-                      description     = _description,
-                      export_function = export_data,
-                      extension       = "ged",
-                      config          = _config )
-pmgr.register_plugin(plugin)
