@@ -20,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: ExportGeneWeb.py 12842 2009-07-28 04:28:12Z pez4brian $
+# $Id: ExportGeneWeb.py 14397 2010-02-16 02:57:46Z dsblank $
 
 "Export to GeneWeb."
 
@@ -30,14 +30,7 @@
 #
 #-------------------------------------------------------------------------
 import os
-from gettext import gettext as _
-
-#-------------------------------------------------------------------------
-#
-# GNOME/GTK modules
-#
-#-------------------------------------------------------------------------
-from gtk import glade
+from gen.ggettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -53,15 +46,16 @@ log = logging.getLogger(".WriteGeneWeb")
 #
 #-------------------------------------------------------------------------
 import gen.lib
-from Filters import GenericFilter, Rules, build_filter_menu
+from Filters import GenericFilter, Rules, build_filter_model
 #import const
 import Utils
 from QuestionDialog import ErrorDialog
-from gen.plug import PluginManager, ExportPlugin
+from glade import Glade
+import config
 
 #-------------------------------------------------------------------------
 #
-#
+# GeneWebWriterOptionBox class
 #
 #-------------------------------------------------------------------------
 class GeneWebWriterOptionBox(object):
@@ -75,17 +69,13 @@ class GeneWebWriterOptionBox(object):
 
     def get_option_box(self):
         self.restrict = 1
-        self.private = 1
 
-        glade_file = os.path.join(os.path.dirname(__file__), 
-                                  "ExportGeneWeb.glade")
-
-        self.topDialog = glade.XML(glade_file, "genewebExport", "gramps")
-        self.topDialog.signal_autoconnect({
+        self.topDialog = Glade()
+        self.topDialog.connect_signals({
                 "on_restrict_toggled": self.on_restrict_toggled
                 })
 
-        filter_obj = self.topDialog.get_widget("filter")
+        self.filters = self.topDialog.get_object("filter")
         self.copy = 0
 
         all = GenericFilter()
@@ -117,37 +107,33 @@ class GeneWebWriterOptionBox(object):
 
         from Filters import CustomFilters
         the_filters.extend(CustomFilters.get_filters('Person'))
-        self.filter_menu = build_filter_menu(the_filters)
-        filter_obj.set_menu(self.filter_menu)
+        self.filter_menu = build_filter_model(the_filters)
+        self.filters.set_model(self.filter_menu)
+        self.filters.set_active(0)
 
-        the_box = self.topDialog.get_widget('vbox1')
-        the_parent = self.topDialog.get_widget('dialog-vbox1')
+        the_box = self.topDialog.get_object('vbox1')
+        the_parent = self.topDialog.get_object('dialog-vbox1')
         the_parent.remove(the_box)
-        self.topDialog.get_widget("genewebExport").destroy()
+        self.topDialog.toplevel.destroy()
         return the_box
 
     def on_restrict_toggled(self, restrict):
         active = restrict.get_active ()
-        for x in [self.topDialog.get_widget("living"),
-                  self.topDialog.get_widget("notes"),
-                  self.topDialog.get_widget("sources")]:
+        for x in [self.topDialog.get_object("living"),
+                  self.topDialog.get_object("notes")]:
             x.set_sensitive(active)
 
     def parse_options(self):
-        self.restrict = self.topDialog.get_widget("restrict").get_active()
+        self.restrict = self.topDialog.get_object("restrict").get_active()
         self.living = (self.restrict and
-                       self.topDialog.get_widget("living").get_active())
+                       self.topDialog.get_object("living").get_active())
         self.exclnotes = (self.restrict and
-                          self.topDialog.get_widget("notes").get_active())
-        self.exclsrcs = (self.restrict and
-                         self.topDialog.get_widget("sources").get_active())
-        self.private = self.topDialog.get_widget("private").get_active()
+                          self.topDialog.get_object("notes").get_active())
+        self.cfilter = self.filter_menu[self.filters.get_active()][1]
 
-        self.cfilter = self.filter_menu.get_active().get_data("filter")
-
-        self.images = self.topDialog.get_widget ("images").get_active ()
+        self.images = self.topDialog.get_object ("images").get_active ()
         if self.images:
-            images_path = self.topDialog.get_widget ("images_path")
+            images_path = self.topDialog.get_object ("images_path")
             self.images_path = unicode(images_path.get_text ())
         else:
             self.images_path = ""
@@ -173,7 +159,6 @@ class GeneWebWriter(object):
         
         if not option_box:
             self.restrict = 0
-            self.private = 0
             self.copy = 0
             self.images = 0
         else:
@@ -182,8 +167,6 @@ class GeneWebWriter(object):
             self.restrict = self.option_box.restrict
             self.living = self.option_box.living
             self.exclnotes = self.option_box.exclnotes
-            self.exclsrcs = self.option_box.exclsrcs
-            self.private = self.option_box.private
             self.copy = self.option_box.copy
             self.images = self.option_box.images
             self.images_path = self.option_box.images_path
@@ -191,8 +174,7 @@ class GeneWebWriter(object):
             if not option_box.cfilter.is_empty():
                 self.db = gen.proxy.FilterProxyDb(self.db, option_box.cfilter)
 
-        for p in self.db.get_person_handles(sort_handles=False):
-            self.plist[p] = 1
+        self.plist.update([p, 1] for p in self.db.iter_person_handles())
             
         self.flist = {}
         for key in self.plist:
@@ -263,7 +245,14 @@ class GeneWebWriter(object):
                 mother_handle = family.get_mother_handle()
                 if mother_handle:
                     mother = self.db.get_person_from_handle(mother_handle)
-                    self.writeln("fam %s %s +%s %s %s" % (self.get_ref_name(father), self.get_full_person_info_fam(father), self.get_wedding_data(family), self.get_ref_name(mother), self.get_full_person_info_fam(mother)))
+                    self.writeln("fam %s %s +%s %s %s" %
+                            (self.get_ref_name(father), 
+                            self.get_full_person_info_fam(father), 
+                            self.get_wedding_data(family), 
+                            self.get_ref_name(mother), 
+                            self.get_full_person_info_fam(mother)
+                            )
+                         )
                     self.write_witness( family)
                     self.write_sources( family.get_source_references())
                     self.write_children( family, father)
@@ -273,8 +262,7 @@ class GeneWebWriter(object):
                         note = ""
                         for notehandle in notelist:
                             noteobj = self.db.get_note_from_handle(notehandle)
-                            note += noteobj.get()
-                            note += " "
+                            note += noteobj.get() + " "
                         if note and note != "":
                             note = note.replace('\n\r',' ')
                             note = note.replace('\r\n',' ')
@@ -296,15 +284,20 @@ class GeneWebWriter(object):
                 if w_list:
                     for witness in w_list:
                         if witness and witness.type == gen.lib.Event.ID:
-                            person = self.db.get_person_from_handle(witness.get_value())
+                            person = self.db.get_person_from_handle(
+                                                        witness.get_value())
                             if person:
                                 gender = ""
                                 if person.get_gender() == gen.lib.Person.MALE:
                                     gender = "h"
                                 elif person.get_gender() == gen.lib.Person.FEMALE:
                                     gender = "f"
-                                self.writeln("wit %s %s %s" % (gender, self.get_ref_name(person), self.get_full_person_info_fam(person)))
-                            
+                                self.writeln("wit %s %s %s" % 
+                                        (gender, 
+                                        self.get_ref_name(person), 
+                                        self.get_full_person_info_fam(person)
+                                        )
+                                    )
 
     def write_sources(self,reflist):
         if self.restrict and self.exclnotes:
@@ -316,7 +309,9 @@ class GeneWebWriter(object):
                 if sbase:
                     source = self.db.get_source_from_handle(sbase)
                     if source:
-                        self.writeln( "src %s" % (self.rem_spaces(source.get_title())))
+                        self.writeln( "src %s" % 
+                            (self.rem_spaces(source.get_title()))
+                            )
 
     def write_children(self,family, father):
         father_lastname = father.get_primary_name().get_surname()
@@ -331,7 +326,12 @@ class GeneWebWriter(object):
                         gender = "h"
                     elif child.get_gender() == gen.lib.Person.FEMALE:
                         gender = "f"
-                    self.writeln("- %s %s %s" % (gender, self.get_child_ref_name(child, father_lastname), self.get_full_person_info_child(child)))
+                    self.writeln("- %s %s %s" % 
+                            (gender, 
+                            self.get_child_ref_name(child, father_lastname), 
+                            self.get_full_person_info_child(child)
+                            )
+                         )
             self.writeln("end")
 
     def write_notes(self,family, father, mother):
@@ -450,26 +450,28 @@ class GeneWebWriter(object):
         return str.replace(' ','_')
     
     def get_ref_name(self,person):
+        missing_surname = config.get("preferences.no-surname-text")
         surname = self.rem_spaces( person.get_primary_name().get_surname())
-        firstname = _("Living")
-        if not (Utils.probably_alive(person,self.db) and self.restrict and self.living):
+        firstname = config.get('preferences.private-given-text') 
+        if not (Utils.probably_alive(person,self.db) and \
+          self.restrict and self.living):
             firstname = self.rem_spaces( person.get_primary_name().get_first_name())
         if person.get_handle() not in self.person_ids:
             self.person_ids[person.get_handle()] = len(self.person_ids)
-        ret = "%s %s.%d" % (surname, firstname, self.person_ids[person.get_handle()])
-        return ret
+        return "%s %s.%d" % (surname or missing_surname, firstname, 
+                             self.person_ids[person.get_handle()])
 
     def get_child_ref_name(self,person,father_lastname):
+        missing_first_name = config.get("preferences.no-given-text")
         surname = self.rem_spaces( person.get_primary_name().get_surname())
-        firstname = _("Living")
-        if not (Utils.probably_alive(person,self.db) and self.restrict and self.living):
+        firstname = config.get('preferences.private-given-text')
+        if not (Utils.probably_alive(person,self.db) and \
+          self.restrict and self.living):
             firstname = self.rem_spaces( person.get_primary_name().get_first_name())
         if person.get_handle() not in self.person_ids:
             self.person_ids[person.get_handle()] = len(self.person_ids)
-        if surname != father_lastname:
-            ret = "%s.%d %s" % (firstname, self.person_ids[person.get_handle()], surname)
-        else:
-            ret = "%s.%d" % (firstname, self.person_ids[person.get_handle()])
+        ret = "%s.%d" % (firstname or missing_first_name, self.person_ids[person.get_handle()])
+        if surname != father_lastname: ret += " " + surname
         return ret
 
     def get_wedding_data(self,family):
@@ -610,19 +612,3 @@ class GeneWebWriter(object):
 def exportData(database, filename, option_box=None, callback=None):
     gw = GeneWebWriter(database, filename, option_box, callback)
     return gw.export_data()
-
-#------------------------------------------------------------------------
-#
-# Register with the plugin system
-#
-#------------------------------------------------------------------------
-_description = _('GeneWeb is a web based genealogy program.')
-_config = (_('GeneWeb export options'), GeneWebWriterOptionBox)
-
-pmgr = PluginManager.get_instance()
-plugin = ExportPlugin(name            = _('_GeneWeb'), 
-                      description     = _description,
-                      export_function = exportData,
-                      extension       = "gw",
-                      config          = _config )
-pmgr.register_plugin(plugin)
