@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: $
+# $Id: WhatsNext.py 14148 2010-01-27 12:07:25Z dsblank $
 
 #------------------------------------------------------------------------
 #
@@ -27,10 +27,10 @@
 #
 #------------------------------------------------------------------------
 from gen.lib import EventType, FamilyRelType, MarkerType
-from BasicUtils import name_displayer
-from DataViews import register, Gramplet
+from gen.plug import Gramplet
+from gen.display.name import displayer as name_displayer
 from ReportBase import ReportUtils
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
 
 #------------------------------------------------------------------------
 #
@@ -97,6 +97,7 @@ class WhatNextGramplet(Gramplet):
 
         self.set_text("")
 
+
         # List of already processed persons and families, to avoid recursing
         # back down to ourselves or meeting the same person through different
         # paths.
@@ -110,7 +111,7 @@ class WhatNextGramplet(Gramplet):
         # parent's other spouses, the ancestors of my grandchildren's spouses,
         # the ancestors of my sibling's spouses etc.
         ancestors = [[default_person]]
-        ancestors_queue = [[[default_person]]] + [[]] * self.ANCESTOR_DELAY
+        ancestors_queue = [[[default_person]]] + [[] for i in range(self.ANCESTOR_DELAY)]
 
         # List of lists of families of relatives in currently processed
         # distance. We go up one level of distance in each round.
@@ -130,12 +131,12 @@ class WhatNextGramplet(Gramplet):
         # beginning of this class definition, but the principle remains the
         # same.
         families = []
-        families_queue = [[]] * self.ANCESTOR_DELAY
+        families_queue = [[] for i in range(self.ANCESTOR_DELAY)]
 
         # List of spouses to add to ancestors list so we track ancestors of
         # spouses, too, but delayed as defined by the parameter.
         spouses = []
-        spouses_queue = [[]] * self.SPOUSE_DELAY
+        spouses_queue = [[] for i in range(self.SPOUSE_DELAY)]
 
         while (ancestors or families):
             # (Other) families of parents
@@ -511,17 +512,3 @@ class UnknownFamilyClass(object):
 
 UnknownPerson = UnknownPersonClass()
 UnknownFamily = UnknownFamilyClass()
-
-#------------------------------------------------------------------------
-#
-# Register the gramplet
-#
-#------------------------------------------------------------------------
-register(
-        type = "gramplet", 
-        name = "What's Next Gramplet", 
-        tname =_("What's Next Gramplet"), 
-        height = 230,
-        expand = True,
-        content = WhatNextGramplet,
-        title = _("What's Next?"))
