@@ -19,8 +19,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#
-# $Id: $
+
+# $Id: ImportProGen.py 14615 2010-03-04 13:58:08Z ldnp $
 
 "Import from Pro-Gen"
 
@@ -30,7 +30,7 @@
 #
 #-------------------------------------------------------------------------
 import re
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 import os
 import struct
 
@@ -48,10 +48,9 @@ log = logging.getLogger('.ImportProGen')
 #
 #-------------------------------------------------------------------------
 import Utils
+from gui.utils import ProgressMeter
 import gen.lib
 from QuestionDialog import ErrorDialog
-from gen.plug import PluginManager, ImportPlugin
-
 
 class ProgenError(Exception):
     """Error used to report Progen errors."""
@@ -138,7 +137,6 @@ def _read_recs(table, bname):
         recs.append(tups)
 
     log.info("# length %s.recs[] = %d" % (table['name1'], len(recs)))
-    print "# length %s.recs[] = %d" % (table['name1'], len(recs))
     return recs
 
 
@@ -192,7 +190,7 @@ def _get_mem_text(mems, i):
     if i <= 0:
         return ''
 
-    i = i - 1
+    i -= 1
     recno = mems[i][0]
     text = mems[i][1].decode('cp850')
     if recno != 0:
@@ -488,7 +486,7 @@ class ProgenParser(object):
         self.skeys = {}                 # Caching source handles
 
     def parse_progen_file(self):
-        self.progress = Utils.ProgressMeter(_("Import from Pro-Gen"), '')
+        self.progress = ProgressMeter(_("Import from Pro-Gen"), '')
 
         self.def_ = PG30_Def(self.fname)
         #print self.def_.diag()
@@ -690,7 +688,8 @@ class ProgenParser(object):
             date.set(gen.lib.Date.QUAL_NONE, gen.lib.Date.MOD_ABOUT, gen.lib.Date.CAL_GREGORIAN, (0, month, year, None))
             return date
 
-        log.warning(_("date did not match: '%s' (%s)") % (txt.encode('utf-8'), diag_msg or ''))
+        log.warning(_("date did not match: '%(text)s' (%(msg)s)") % {
+            'text' : txt.encode('utf-8'), 'msg' : diag_msg or '' } )
         # Hmmm. Just use the plain text.
         date.set_as_text(txt)
         return date
@@ -815,7 +814,7 @@ class ProgenParser(object):
                 per_klad = recflds[per_klad_ix]
                 per_info = recflds[per_info_ix]
 
-                note_txt = [x for x in [per_info, per_klad] if x]
+                note_txt = filter(None, [per_info, per_klad])
                 if note_txt:
                     note = gen.lib.Note()
                     note.set('\n'.join(note_txt))
@@ -861,7 +860,7 @@ class ProgenParser(object):
                 source_text = recflds[birth_source_text_ix]
                 info = recflds[birth_info_ix]
                 if date or place or info or srcref:
-                    desc = [x for x in [info, time, source_text] if x]
+                    desc = filter(None, [info, time, source_text])
                     desc = desc and '; '.join(desc) or None
                     event, birth_ref = self.__create_event_and_ref(gen.lib.EventType.BIRTH, desc, date, place, srcref)
                     person.set_birth_ref(birth_ref)
@@ -884,7 +883,7 @@ class ProgenParser(object):
                 source_text = recflds[bapt_source_text_ix]
                 info = recflds[bapt_info_ix]
                 if date or place or info or srcref or reli or witness:
-                    desc = [x for x in [reli, info, source_text] if x]
+                    desc = filter(None, [reli, info, source_text])
                     desc = desc and '; '.join(desc) or None
                     event, bapt_ref = self.__create_event_and_ref(gen.lib.EventType.BAPTISM, desc, date, place, srcref)
                     person.add_event_ref(bapt_ref)
@@ -920,7 +919,7 @@ class ProgenParser(object):
                 source_text = recflds[death_source_text_ix]
                 info = recflds[death_info_ix]
                 if date or place or info or srcref:
-                    desc = [x for x in [info, time, source_text] if x]
+                    desc = filter(None, [info, time, source_text])
                     desc = desc and '; '.join(desc) or None
                     event, death_ref = self.__create_event_and_ref(gen.lib.EventType.DEATH, desc, date, place, srcref)
                     person.set_death_ref(death_ref)
@@ -941,7 +940,7 @@ class ProgenParser(object):
                 source_text = recflds[bur_source_text_ix]
                 info = recflds[bur_info_ix]
                 if date or place or info or srcref:
-                    desc = [x for x in [info, source_text] if x]
+                    desc = filter(None, [info, source_text])
                     desc = desc and '; '.join(desc) or None
                     event, burial_ref = self.__create_event_and_ref(gen.lib.EventType.BURIAL, desc, date, place, srcref)
                     person.add_event_ref(burial_ref)
@@ -963,7 +962,7 @@ class ProgenParser(object):
                 info = recflds[crem_info_ix]
                 if date or place or info or srcref:
                     # TODO. Check that not both burial and cremation took place.
-                    desc = [x for x in [info, source_text] if x]
+                    desc = filter(None, [info, source_text])
                     desc = desc and '; '.join(desc) or None
                     event, cremation_ref = self.__create_event_and_ref(gen.lib.EventType.CREMATION, desc, date, place, srcref)
                     person.add_event_ref(cremation_ref)
@@ -1075,7 +1074,7 @@ class ProgenParser(object):
                 rel_klad = recflds[rel_klad_ix]
                 rel_info = recflds[rel_info_ix]
 
-                note_txt = [x for x in [rel_info, rel_klad] if x]
+                note_txt = filter(None, [rel_info, rel_klad])
                 if note_txt:
                     note = gen.lib.Note()
                     note.set('\n'.join(note_txt))
@@ -1096,7 +1095,7 @@ class ProgenParser(object):
                 source_text = recflds[mar_source_text_ix]
                 info = recflds[mar_info_ix]
                 if date or place or info or srcref:
-                    desc = [x for x in [info, source_text] if x]
+                    desc = filter(None, [info, source_text])
                     desc = desc and '; '.join(desc) or None
                     event, mar_ref = self.__create_event_and_ref(gen.lib.EventType.MARRIAGE, desc, date, place, srcref)
                     fam.add_event_ref(mar_ref)
@@ -1128,7 +1127,7 @@ class ProgenParser(object):
                 source_text = recflds[marc_source_text_ix]
                 info = recflds[marc_info_ix]
                 if date or place or info or srcref:
-                    desc = [x for x in [reli, info, source_text] if x]
+                    desc = filter(None, [reli, info, source_text])
                     desc.insert(0, 'Kerkelijk huwelijk')
                     desc = desc and '; '.join(desc) or None
                     event, marc_ref = self.__create_event_and_ref(gen.lib.EventType.MARRIAGE, desc, date, place, srcref)
@@ -1160,7 +1159,7 @@ class ProgenParser(object):
                 source_text = recflds[marl_source_text_ix]
                 info = recflds[marl_info_ix]
                 if date or place or info or srcref:
-                    desc = [x for x in [info, source_text] if x]
+                    desc = filter(None, [info, source_text])
                     desc.insert(0, 'Ondertrouw')
                     desc = desc and '; '.join(desc) or None
                     event, marl_ref = self.__create_event_and_ref(gen.lib.EventType.MARR_LIC, desc, date, place, srcref)
@@ -1188,7 +1187,7 @@ class ProgenParser(object):
                 source_text = recflds[civu_source_text_ix]
                 info = recflds[civu_info_ix]
                 if date or place or info or srcref:
-                    desc = [x for x in [info, source_text] if x]
+                    desc = filter(None, [info, source_text])
                     desc.insert(0, 'Samenwonen')
                     desc = desc and '; '.join(desc) or None
                     event, civu_ref = self.__create_event_and_ref(gen.lib.EventType.UNKNOWN, desc, date, place, srcref)
@@ -1212,7 +1211,7 @@ class ProgenParser(object):
                 source_text = recflds[div_source_text_ix]
                 info = recflds[div_info_ix]
                 if date or place or info or srcref:
-                    desc = [x for x in [info, source_text] if x]
+                    desc = filter(None, [info, source_text])
                     desc = desc and '; '.join(desc) or None
                     event, div_ref = self.__create_event_and_ref(gen.lib.EventType.DIVORCE, desc, date, place, srcref)
                     fam.add_event_ref(div_ref)
@@ -1240,9 +1239,11 @@ class ProgenParser(object):
                 father_handle = father > 0 and self.__find_person_handle("I%d" % father) or None
                 mother_handle = mother > 0 and self.__find_person_handle("I%d" % mother) or None
                 if father > 0 and not father_handle:
-                    log.warning(_("cannot find father for I%s (father=%d)") % (pers_id, father))
+                    log.warning(_("cannot find father for I%(person)s (father=%(id)d)") % {
+                        'person' : pers_id, 'id' : father } )
                 elif mother > 0 and not mother_handle:
-                    log.warning(_("cannot find mother for I%s (mother=%d)") % (pers_id, mother))
+                    log.warning(_("cannot find mother for I%(person)s (mother=%(mother)d)") % {
+                        'person' : pers_id, 'mother' : mother } )
                 else:
                     fam = self.fm2fam.get((father_handle, mother_handle), None)
                     if not fam:
@@ -1270,15 +1271,3 @@ class ProgenParser(object):
                     person.add_parent_family_handle(fam.get_handle())
                     self.db.commit_person(person, self.trans)
             self.progress.step()
-                
-#-------------------------------------------------------------------------
-#
-# Register with the plugin system
-#
-#-------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-plugin = ImportPlugin(name            = _('Pro-Gen'), 
-                      description     = _("Import data from Pro-Gen files"),
-                      import_function = _importData,
-                      extension       = "def")
-pmgr.register_plugin(plugin)
