@@ -19,9 +19,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-
-
-
+"""
+Slovak-specific classes for relationships.
+"""
 #-------------------------------------------------------------------------
 #
 # GRAMPS modules
@@ -30,7 +30,6 @@
 
 import gen.lib
 import Relationship
-from gen.plug import PluginManager
 
 #-------------------------------------------------------------------------
 #
@@ -76,9 +75,9 @@ _sister_level = [ "", "sestra%s", "teta%s", "prateta%s", "praprateta%s", ]
 
 _brother_level = [ "", "brat%s", "strýko%s", "prastrýko%s", "praprastrýko%s", ]
 
-_nephew_level =[ "", "synovec%s", "prasynovec%s", "praprasynovec%s", ]
+_nephew_level = [ "", "synovec%s", "prasynovec%s", "praprasynovec%s", ]
 
-_niece_level =[ "", "neter%s", "praneter%s", "prapraneter%s", ]
+_niece_level = [ "", "neter%s", "praneter%s", "prapraneter%s", ]
 
 # kinship report
 
@@ -107,6 +106,9 @@ _nephews_nieces_level = [ "", "synovci a netere",
 #-------------------------------------------------------------------------
 
 class RelationshipCalculator(Relationship.RelationshipCalculator):
+    """
+    RelationshipCalculator Class
+    """
    
     INLAW = ' (m. zväzok)'
 
@@ -223,7 +225,10 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
 
 # kinship report
 
-    def get_plural_relationship_string(self, Ga, Gb):
+    def get_plural_relationship_string(self, Ga, Gb,
+                                       reltocommon_a='', reltocommon_b='',
+                                       only_birth=True,
+                                       in_law_a=False, in_law_b=False):
         """
         see Relationship.py
         """
@@ -287,8 +292,6 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
             elif Ga < len(_level_name):
                 rel_str = "prastrýkovia a pratety" + bygen % (
                                Ga+1)
-            else:
-                return rel_str
         elif Gb > 1 and Gb > Ga:
             # These are cousins in different generations with the second person 
             # being in a lower generation from the common ancestor than the 
@@ -305,8 +308,10 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
             elif Ga < len(_level_name):
                 rel_str =  "synovci a netere" + bygen % (
                                 Gb)
-            else:
-                return rel_str
+        if in_law_b == True:
+            # TODO: Translate this!
+            rel_str = "spouses of %s" % rel_str
+            
         return rel_str
 
 
@@ -573,27 +578,17 @@ class RelationshipCalculator(Relationship.RelationshipCalculator):
         return rel_str
 
 
-#-------------------------------------------------------------------------
-#
-# Register this class with the Plugins system 
-#
-#-------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_relcalc(RelationshipCalculator, 
-    ["sk", "SK", "sk_SK", "slovensky", "slovak", "Slovak", "sk_SK.UTF8", "sk_SK.UTF-8", "sk_SK.utf-8", "sk_SK.utf8"])
-
-
 if __name__ == "__main__":
     # Test function. Call it as follows from the command line (so as to find
     #        imported modules):
     #    export PYTHONPATH=/path/to/gramps/src 
-    # python src/plugins/rel_sk.py 
+    # python src/plugins/rel/rel_sk.py 
     # (Above not needed here)
     
     """TRANSLATORS, copy this if statement at the bottom of your 
         rel_xx.py module, and test your work with:
-        python src/plugins/rel_xx.py
+        python src/plugins/rel/rel_xx.py
     """
     from Relationship import test
-    rc = RelationshipCalculator()
-    test(rc, True)
+    RC = RelationshipCalculator()
+    test(RC, True)
