@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2000-2002 Bruce J. DeGrasse
 # Copyright (C) 2000-2007 Donald N. Allingham
-# Copyright (C) 2007-2008 Brian G. Matherly
+# Copyright (C) 2007-2009 Brian G. Matherly
 # Copyright (C) 2008      James Friedmann <jfriedmannj@gmail.com>
 # Copyright (C) 2009      Benny Malengier <benny.malengier@gramps-project.org>
 #
@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DetAncestralReport.py 12842 2009-07-28 04:28:12Z pez4brian $
+# $Id: DetAncestralReport.py 15168 2010-04-16 20:58:51Z bmcage $
 
 """Reports/Text Reports/Detailed Ancestral Report"""
 
@@ -31,22 +31,25 @@
 # standard python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import gen.lib
-from gen.plug import PluginManager
+from gen.display.name import displayer as _nd
+from Errors import ReportError
+from gen.lib import EventType, FamilyRelType, Person, NoteType
+from gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle,
+                            FONT_SANS_SERIF, FONT_SERIF, 
+                            INDEX_TYPE_TOC, PARA_ALIGN_CENTER)
 from gen.plug.menu import BooleanOption, NumberOption, PersonOption
-from ReportBase import Report, ReportUtils, MenuReportOptions, CATEGORY_TEXT
-from ReportBase import Bibliography, Endnotes
-import BaseDoc
+from ReportBase import (Report, ReportUtils, MenuReportOptions,
+                        Bibliography, Endnotes)
 import DateHandler
-from BasicUtils import name_displayer as _nd
-import Utils
+
+from libnarrate import Narrator
 
 #------------------------------------------------------------------------
 #
@@ -101,7 +104,7 @@ class DetAncestorReport(Report):
         self.fulldate      = menu.get_option_by_name('fulldates').get_value()
         self.listchildren  = menu.get_option_by_name('listc').get_value()
         self.includenotes  = menu.get_option_by_name('incnotes').get_value()
-        self.usecall       = menu.get_option_by_name('usecall').get_value()
+        use_call           = menu.get_option_by_name('usecall').get_value()
         blankplace         = menu.get_option_by_name('repplace').get_value()
         blankdate          = menu.get_option_by_name('repdate').get_value()
         self.calcageflag   = menu.get_option_by_name('computeage').get_value()
@@ -113,26 +116,33 @@ class DetAncestorReport(Report):
         self.inc_events    = menu.get_option_by_name('incevents').get_value()
         self.inc_addr      = menu.get_option_by_name('incaddresses').get_value()
         self.inc_sources   = menu.get_option_by_name('incsources').get_value()
+        self.inc_srcnotes  = menu.get_option_by_name('incsrcnotes').get_value()
         self.inc_attrs     = menu.get_option_by_name('incattrs').get_value()
         pid                = menu.get_option_by_name('pid').get_value()
         self.center_person = database.get_person_from_gramps_id(pid)
+        if (self.center_person == None) :
+            raise ReportError(_("Person %s is not in the Database") % pid )
 
         self.gen_handles = {}
         self.prev_gen_handles = {}
         
         if blankdate:
-            self.EMPTY_DATE = EMPTY_ENTRY
+            empty_date = EMPTY_ENTRY
         else:
-            self.EMPTY_DATE = ""
+            empty_date = ""
 
         if blankplace:
-            self.EMPTY_PLACE = EMPTY_ENTRY
+            empty_place = EMPTY_ENTRY
         else:
-            self.EMPTY_PLACE = ""
+            empty_place = ""
+            
+        self.__narrator = Narrator(self.database, self.verbose, use_call, 
+                                   empty_date, empty_place, 
+                                   get_endnote_numbers=self.endnotes)
 
         self.bibli = Bibliography(Bibliography.MODE_PAGE)
 
-    def apply_filter(self,person_handle,index):
+    def apply_filter(self, person_handle, index):
         if (not person_handle) or (index >= 2**self.max_generations):
             return
         self.map[index] = person_handle
@@ -141,34 +151,31 @@ class DetAncestorReport(Report):
         family_handle = person.get_main_parents_family_handle()
         if family_handle:
             family = self.database.get_family_from_handle(family_handle)
-            self.apply_filter(family.get_father_handle(),index*2)
-            self.apply_filter(family.get_mother_handle(),(index*2)+1)
+            self.apply_filter(family.get_father_handle(), index*2)
+            self.apply_filter(family.get_mother_handle(), (index*2)+1)
 
     def write_report(self):
-        self.apply_filter(self.center_person.get_handle(),1)
+        self.apply_filter(self.center_person.get_handle(), 1)
 
         name = _nd.display_name(self.center_person.get_primary_name())
         self.doc.start_paragraph("DAR-Title")
         title = _("Ancestral Report for %s") % name
-        mark = BaseDoc.IndexMark(title,BaseDoc.INDEX_TYPE_TOC,1)
-        self.doc.write_text(title,mark)
+        mark = IndexMark(title, INDEX_TYPE_TOC, 1)
+        self.doc.write_text(title, mark)
         self.doc.end_paragraph()
 
-        keys = self.map.keys()
-        keys.sort()
         generation = 0
-        need_header = 1
 
-        for key in keys :
+        for key in sorted(self.map):
             if generation == 0 or key >= 2**generation:
                 if self.pgbrk and generation > 0:
                     self.doc.page_break()
                 self.doc.start_paragraph("DAR-Generation")
                 text = _("Generation %d") % (generation+1)
-                mark = BaseDoc.IndexMark(text, BaseDoc.INDEX_TYPE_TOC, 2)
+                mark = IndexMark(text, INDEX_TYPE_TOC, 2)
                 self.doc.write_text(text, mark)
                 self.doc.end_paragraph()
-                generation = generation + 1
+                generation += 1
                 if self.childref:
                     self.prev_gen_handles = self.gen_handles.copy()
                     self.gen_handles.clear()
@@ -182,9 +189,9 @@ class DetAncestorReport(Report):
                     for family_handle in person.get_family_handle_list():
                         family = self.database.get_family_from_handle(family_handle)
                         mother_handle = family.get_mother_handle()
-                        if mother_handle is None                         or    \
-                           mother_handle not in self.map.values()        or    \
-                           person.get_gender() == gen.lib.Person.FEMALE:
+                        if (mother_handle is None                      or
+                            mother_handle not in self.map.itervalues()  or
+                            person.get_gender() == Person.FEMALE):
                             # The second test above also covers the 1. person's
                             # mate, which is not an ancestor and as such is not
                             # included in the self.map dictionary
@@ -193,7 +200,8 @@ class DetAncestorReport(Report):
                             if self.inc_events:
                                 self.write_family_events(family)
         if self.inc_sources:
-            Endnotes.write_endnotes(self.bibli,self.database,self.doc)
+            Endnotes.write_endnotes(self.bibli, self.database, self.doc,
+                                    printnotes=self.inc_srcnotes)
 
     def write_person(self, key):
         """Output birth, death, parentage, marriage and notes information """
@@ -201,10 +209,11 @@ class DetAncestorReport(Report):
         person_handle = self.map[key]
         person = self.database.get_person_from_handle(person_handle)
         plist = person.get_media_list()
+        self.__narrator.set_subject(person)
         
         if self.addimages and len(plist) > 0:
             photo = plist[0]
-            ReportUtils.insert_image(self.database,self.doc,photo)
+            ReportUtils.insert_image(self.database, self.doc, photo)
 
         self.doc.start_paragraph("DAR-First-Entry","%s." % str(key))
 
@@ -212,7 +221,7 @@ class DetAncestorReport(Report):
         mark = ReportUtils.get_person_mark(self.database, person)
 
         self.doc.start_bold()
-        self.doc.write_text(name,mark)
+        self.doc.write_text(name, mark)
         if name[-1:] == '.':
             self.doc.write_text_citation("%s " % self.endnotes(person))
         else:
@@ -221,9 +230,7 @@ class DetAncestorReport(Report):
 
         if self.dupperson:
             # Check for duplicate record (result of distant cousins marrying)
-            keys = self.map.keys()
-            keys.sort()
-            for dkey in keys:
+            for dkey in sorted(self.map):
                 if dkey >= key: 
                     break
                 if self.map[key] == self.map[dkey]:
@@ -232,56 +239,32 @@ class DetAncestorReport(Report):
                         { 'name' : '', 'id_str' : str(dkey) })
                     self.doc.end_paragraph()
                     return 1    # Duplicate person
-
-        # Check birth record
-
-        first = ReportUtils.common_name(person,self.usecall)
         
         if not self.verbose:
-            self.write_parents(person, first)
+            self.write_parents(person)
 
-        text = ReportUtils.born_str(self.database, person, first, self.verbose,
-                                    self.EMPTY_DATE, self.EMPTY_PLACE)
+        text = self.__narrator.get_born_string()
         if text:
-            birth_ref = person.get_birth_ref()
-            if birth_ref:
-                birth = self.database.get_event_from_handle(birth_ref.ref)
-                text = text.rstrip(". ")
-                text = text + self.endnotes(birth) + ". "
             self.doc.write_text_citation(text)
-            first = 0
 
-        text = ReportUtils.baptised_str(self.database, person, first, self.verbose,
-                                        self.endnotes, self.EMPTY_DATE, self.EMPTY_PLACE)
+        text = self.__narrator.get_baptised_string()
         if text:
             self.doc.write_text_citation(text)
             
-        text = ReportUtils.christened_str(self.database, person, first, self.verbose,
-                                        self.endnotes, self.EMPTY_DATE, self.EMPTY_PLACE)
+        text = self.__narrator.get_christened_string()
         if text:
             self.doc.write_text_citation(text)
 
-        span = self.calc_age(person)
-        text = ReportUtils.died_str(self.database, person, first, self.verbose,
-                                    self.EMPTY_DATE, self.EMPTY_PLACE, span)
-        if text:
-            death_ref = person.get_death_ref()
-            if death_ref:
-                death = self.database.get_event_from_handle(death_ref.ref)
-                text = text.rstrip(". ")
-                text = text + self.endnotes(death) + ". "
-            self.doc.write_text_citation(text)
-            first = 0
-
-        text = ReportUtils.buried_str(self.database, person, first, self.verbose,
-                                        self.endnotes, self.EMPTY_DATE, self.EMPTY_PLACE)
+        text = self.__narrator.get_died_string(self.calcageflag)
         if text:
             self.doc.write_text_citation(text)
 
-        first = ReportUtils.common_name(person,self.usecall)
+        text = self.__narrator.get_buried_string()
+        if text:
+            self.doc.write_text_citation(text)
 
         if self.verbose:
-            self.write_parents(person, first)
+            self.write_parents(person)
 
         if not key % 2 or key == 1:
             self.write_marriage(person)
@@ -298,7 +281,9 @@ class DetAncestorReport(Report):
             for notehandle in notelist:
                 note = self.database.get_note_from_handle(notehandle)
                 self.doc.write_styled_note(note.get_styledtext(), 
-                                           note.get_format(),"DAR-Entry")
+                                           note.get_format(), "DAR-Entry",
+                                           contains_html= note.get_type() \
+                                                        == NoteType.HTML_CODE)
 
         first = True
         if self.inc_names:
@@ -434,9 +419,11 @@ class DetAncestorReport(Report):
             for notehandle in notelist:
                 note = self.database.get_note_from_handle(notehandle)
                 self.doc.write_styled_note(note.get_styledtext(), 
-                                           note.get_format(),"DAR-MoreDetails")
+                                           note.get_format(),"DAR-MoreDetails",
+                                           contains_html= note.get_type() \
+                                                        == NoteType.HTML_CODE)
                 
-    def write_parents(self, person, firstName):
+    def write_parents(self, person):
         family_handle = person.get_main_parents_family_handle()
         if family_handle:
             family = self.database.get_family_from_handle(family_handle)
@@ -456,16 +443,14 @@ class DetAncestorReport(Report):
             else:
                 father_name = ""
                 father_mark = ""
-            alive = Utils.probably_alive(person, self.database)
-            text = ReportUtils.child_str(person, father_name, mother_name,
-                                         not alive,
-                                         firstName,self.verbose)
+
+            text = self.__narrator.get_child_string(father_name, mother_name)
             if text:
                 self.doc.write_text(text)
                 if father_mark:
-                    self.doc.write_text("",father_mark)
+                    self.doc.write_text("", father_mark)
                 if mother_mark:
-                    self.doc.write_text("",mother_mark)
+                    self.doc.write_text("", mother_mark)
 
     def write_marriage(self, person):
         """ 
@@ -479,14 +464,10 @@ class DetAncestorReport(Report):
             text = ""
             spouse_mark = ReportUtils.get_person_mark(self.database, spouse)
             
-            text = ReportUtils.married_str(self.database,person,family,
-                                            self.verbose,
-                                            self.endnotes,
-                                            self.EMPTY_DATE,self.EMPTY_PLACE,
-                                            is_first)
+            text = self.__narrator.get_married_string(family, is_first)
 
             if text:
-                self.doc.write_text_citation(text,spouse_mark)
+                self.doc.write_text_citation(text, spouse_mark)
                 is_first = False
 
     def write_children(self, family):
@@ -522,26 +503,26 @@ class DetAncestorReport(Report):
             child_handle = child_ref.ref
             child = self.database.get_person_from_handle(child_handle)
             child_name = _nd.display(child)
-            child_mark = ReportUtils.get_person_mark(self.database,child)
+            child_mark = ReportUtils.get_person_mark(self.database, child)
 
             if self.childref and self.prev_gen_handles.get(child_handle):
                 value = str(self.prev_gen_handles.get(child_handle))
                 child_name += " [%s]" % value
 
-            self.doc.start_paragraph("DAR-ChildList",ReportUtils.roman(cnt).lower() + ".")
+            self.doc.start_paragraph("DAR-ChildList",
+                                     ReportUtils.roman(cnt).lower() + ".")
             cnt += 1
 
-            self.doc.write_text("%s. " % child_name,child_mark)
-            self.doc.write_text(
-                        ReportUtils.born_str(self.database, child, 0, 
-                            self.verbose, self.EMPTY_DATE, self.EMPTY_PLACE))
-            self.doc.write_text(
-                        ReportUtils.died_str(self.database, child, 0, 
-                            self.verbose, self.EMPTY_DATE, self.EMPTY_PLACE))
-            
+            self.__narrator.set_subject(child)
+            self.doc.write_text("%s. " % child_name, child_mark)
+            self.doc.write_text_citation(self.__narrator.get_born_string() or
+                                self.__narrator.get_christened_string() or
+                                self.__narrator.get_baptised_string())
+            self.doc.write_text_citation(self.__narrator.get_died_string() or
+                                self.__narrator.get_buried_string())
             self.doc.end_paragraph()
 
-    def write_family_events(self,family):
+    def write_family_events(self, family):
         
         if not family.get_event_ref_list():
             return
@@ -580,7 +561,7 @@ class DetAncestorReport(Report):
         for family_handle in person.get_family_handle_list():
             family = self.database.get_family_from_handle(family_handle)
             ind_handle = None
-            if person.get_gender() == gen.lib.Person.MALE:
+            if person.get_gender() == Person.MALE:
                 ind_handle = family.get_mother_handle()
             else:
                 ind_handle = family.get_father_handle()
@@ -590,10 +571,10 @@ class DetAncestorReport(Report):
                     event = self.database.get_event_from_handle(event_ref.ref)
                     if event:
                         etype = event.get_type()
-                        if etype == gen.lib.EventType.BAPTISM or \
-                           etype == gen.lib.EventType.BURIAL or \
-                           etype == gen.lib.EventType.BIRTH  or \
-                           etype == gen.lib.EventType.DEATH     :
+                        if etype == EventType.BAPTISM or \
+                           etype == EventType.BURIAL or \
+                           etype == EventType.BIRTH  or \
+                           etype == EventType.DEATH     :
                             has_info = True
                             break   
                 if not has_info:
@@ -616,7 +597,7 @@ class DetAncestorReport(Report):
                 name = _nd.display_formal(ind)
                 mark = ReportUtils.get_person_mark(self.database, ind)
         
-                if family.get_relationship() == gen.lib.FamilyRelType.MARRIED:
+                if family.get_relationship() == FamilyRelType.MARRIED:
                     self.doc.write_text(_("Spouse: %s") % name, mark)
                 else:
                     self.doc.write_text(_("Relationship with: %s") % name, mark)
@@ -627,67 +608,32 @@ class DetAncestorReport(Report):
 
                 self.doc.start_paragraph("DAR-Entry")
 
-                first_name = ReportUtils.common_name(ind, self.usecall)
-                print_name = first_name
+                self.__narrator.set_subject(ind)
 
-                text = ReportUtils.born_str(self.database, ind, print_name, 
-                            self.verbose, self.EMPTY_DATE, self.EMPTY_PLACE)
-                if text:
-                    self.doc.write_text(text)
-                    print_name = 0
-
-                text = ReportUtils.baptised_str(self.database, ind, print_name, 
-                            self.verbose, self.endnotes, self.EMPTY_DATE, 
-                            self.EMPTY_PLACE)
+                text = self.__narrator.get_born_string()
                 if text:
                     self.doc.write_text_citation(text)
-                    print_name = 0
 
-                text = ReportUtils.christened_str(self.database, ind, print_name, 
-                            self.verbose, self.endnotes, self.EMPTY_DATE, 
-                            self.EMPTY_PLACE)
+                text = self.__narrator.get_baptised_string()
                 if text:
                     self.doc.write_text_citation(text)
-                    print_name = 0
 
-                span = self.calc_age(ind)
-                text = ReportUtils.died_str(self.database, ind, print_name, 
-                           self.verbose, self.EMPTY_DATE, self.EMPTY_PLACE,
-                           span)
+                text = self.__narrator.get_christened_string()
                 if text:
-                    self.doc.write_text(text)
-                    print_name = 0
-                
-                text = ReportUtils.buried_str(self.database, ind, print_name,
-                        self.verbose, self.endnotes, self.EMPTY_DATE, 
-                        self.EMPTY_PLACE)
+                    self.doc.write_text_citation(text)
+
+                text = self.__narrator.get_died_string(self.calcageflag)
+                if text:
+                    self.doc.write_text_citation(text)
                 
+                text = self.__narrator.get_buried_string()
                 if text:
                     self.doc.write_text_citation(text)
-                    print_name = 0
 
-                if print_name == 0:
-                    print_name = first_name
-                self.write_parents(ind, print_name)
+                self.write_parents(ind)
 
                 self.doc.end_paragraph()
 
-    def calc_age(self,ind):
-        """
-        Calulate age. 
-        
-        Returns a tuple (age,units) where units is an integer representing
-        time units:
-            no age info:    0
-            years:          1
-            months:         2
-            days:           3
-        """
-        if self.calcageflag:
-            return ReportUtils.old_calc_age(self.database,ind)
-        else:
-            return None
-
     def endnotes(self, obj):
         if not obj or not self.inc_sources:
             return ""
@@ -742,8 +688,8 @@ class DetAncestorOptions(MenuReportOptions):
         listc.set_help(_("Whether to list children."))
         menu.add_option(category_name,"listc",listc)
         
-        computeage = BooleanOption(_("Compute age"),True)
-        computeage.set_help(_("Whether to compute age."))
+        computeage = BooleanOption(_("Compute death age"),True)
+        computeage.set_help(_("Whether to compute a person's age at death."))
         menu.add_option(category_name,"computeage",computeage)
         
         omitda = BooleanOption(_("Omit duplicate ancestors"),True)
@@ -789,7 +735,12 @@ class DetAncestorOptions(MenuReportOptions):
         incsources = BooleanOption(_("Include sources"),False)
         incsources.set_help(_("Whether to include source references."))
         menu.add_option(category_name,"incsources",incsources)
-        
+
+        incsrcnotes = BooleanOption(_("Include sources notes"), False)
+        incsrcnotes.set_help(_("Whether to include source notes in the "
+            "Endnotes section. Only works if Include sources is selected."))
+        menu.add_option(category_name, "incsrcnotes", incsrcnotes)
+
         category_name = _("Missing information")        
 
         repplace = BooleanOption(_("Replace missing places with ______"),False)
@@ -802,20 +753,20 @@ class DetAncestorOptions(MenuReportOptions):
 
     def make_default_style(self,default_style):
         """Make the default output style for the Detailed Ancestral Report"""
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SANS_SERIF,size=16,bold=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SANS_SERIF,size=16,bold=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set_header_level(1)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)
-        para.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
+        para.set_alignment(PARA_ALIGN_CENTER)
         para.set_description(_('The style used for the title of the page.'))
         default_style.add_paragraph_style("DAR-Title",para)
 
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SANS_SERIF,size=14,italic=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SANS_SERIF,size=14,italic=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set_header_level(2)
         para.set_top_margin(0.25)
@@ -823,9 +774,9 @@ class DetAncestorOptions(MenuReportOptions):
         para.set_description(_('The style used for the generation header.'))
         default_style.add_paragraph_style("DAR-Generation",para)
 
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SANS_SERIF,size=10,italic=0, bold=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SANS_SERIF,size=10,italic=0, bold=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set_left_margin(1.0)   # in centimeters
         para.set_top_margin(0.25)
@@ -833,9 +784,9 @@ class DetAncestorOptions(MenuReportOptions):
         para.set_description(_('The style used for the children list title.'))
         default_style.add_paragraph_style("DAR-ChildTitle",para)
 
-        font = BaseDoc.FontStyle()
+        font = FontStyle()
         font.set(size=10)
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set_font(font)
         para.set(first_indent=-0.75,lmargin=1.75)
         para.set_top_margin(0.25)
@@ -843,32 +794,32 @@ class DetAncestorOptions(MenuReportOptions):
         para.set_description(_('The style used for the children list.'))
         default_style.add_paragraph_style("DAR-ChildList",para)
 
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SANS_SERIF,size=10,italic=0, bold=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SANS_SERIF,size=10,italic=0, bold=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set(first_indent=0.0,lmargin=1.0)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)
         default_style.add_paragraph_style("DAR-NoteHeader",para)
 
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set(lmargin=1.0)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)
         para.set_description(_('The basic style used for the text display.'))
         default_style.add_paragraph_style("DAR-Entry",para)
 
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set(first_indent=-1.0,lmargin=1.0)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)
         para.set_description(_('The style used for the first personal entry.'))
         default_style.add_paragraph_style("DAR-First-Entry",para)
 
-        font = BaseDoc.FontStyle()
-        font.set(size=10,face=BaseDoc.FONT_SANS_SERIF,bold=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(size=10,face=FONT_SANS_SERIF,bold=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set(first_indent=0.0,lmargin=1.0)
         para.set_top_margin(0.25)
@@ -876,9 +827,9 @@ class DetAncestorOptions(MenuReportOptions):
         para.set_description(_('The style used for the More About header.'))
         default_style.add_paragraph_style("DAR-MoreHeader",para)
 
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SERIF,size=10)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SERIF,size=10)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set(first_indent=0.0,lmargin=1.0)
         para.set_top_margin(0.25)
@@ -887,24 +838,3 @@ class DetAncestorOptions(MenuReportOptions):
         default_style.add_paragraph_style("DAR-MoreDetails",para)
 
         Endnotes.add_endnote_styles(default_style)
-
-#------------------------------------------------------------------------
-#
-#
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_report(
-    name = 'det_ancestor_report',
-    category = CATEGORY_TEXT,
-    report_class = DetAncestorReport,
-    options_class = DetAncestorOptions,
-    modes = PluginManager.REPORT_MODE_GUI | \
-            PluginManager.REPORT_MODE_BKI | \
-            PluginManager.REPORT_MODE_CLI,
-    translated_name = _("Detailed Ancestral Report"),
-    status=(_("Stable")),
-    description= _("Produces a detailed ancestral report"),
-    author_name="Bruce DeGrasse",
-    author_email="bdegrasse1@attbi.com"
-    )
