@@ -19,18 +19,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: NotRelated.py 13187 2009-09-10 13:47:37Z romjerome $
+# $Id: NotRelated.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 "Find people who are not related to the selected person"
 
-#------------------------------------------------------------------------
-#
-# standard python modules
-#
-#------------------------------------------------------------------------
-import os
-from gettext import ngettext
-
 #------------------------------------------------------------------------
 #
 # GNOME/GTK modules
@@ -45,15 +37,15 @@ import gobject
 #
 #------------------------------------------------------------------------
 import const
+from gen.ggettext import ngettext
 from PluginUtils import Tool
-from gen.plug import PluginManager
 from ReportBase import ReportUtils
-from PluginUtils import Tool
-from Editors import EditPerson, EditFamily
+from gui.editors import EditPerson, EditFamily
 import ManagedWindow
-import Utils
+from gui.utils import ProgressMeter
 import GrampsDisplay
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
+from glade import Glade
 
 #-------------------------------------------------------------------------
 #
@@ -62,46 +54,51 @@ from TransUtils import sgettext as _
 #-------------------------------------------------------------------------
 WIKI_HELP_PAGE = '%s_-_Tools' % const.URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|Not_Related...')
+
 #------------------------------------------------------------------------
 #
-# 
+# NotRelated class
 #
 #------------------------------------------------------------------------
 class NotRelated(Tool.ActivePersonTool, ManagedWindow.ManagedWindow) :
 
     def __init__(self, dbstate, uistate, options_class, name, callback=None):
-        Tool.ActivePersonTool.__init__(self, dbstate, options_class, name)
+        Tool.ActivePersonTool.__init__(self, dbstate, uistate, options_class,
+                                       name)
 
         if self.fail:   # bug #2709 -- fail if we have no active person
             return
 
-        person = dbstate.get_active_person()
+        person_handle = uistate.get_active('Person')
+        person = dbstate.db.get_person_from_handle(person_handle)
         self.name = person.get_primary_name().get_regular_name()
         self.title = _('Not related to "%s"') % self.name
         ManagedWindow.ManagedWindow.__init__(self, uistate, [], self.__class__)
         self.dbstate = dbstate
         self.uistate = uistate
         self.db = dbstate.db
-        glade_file = "%s/NotRelated.glade" % os.path.dirname(__file__)
-        topDialog = gtk.glade.XML(glade_file, "top", "gramps")
-        topDialog.signal_autoconnect({
+        
+        topDialog = Glade()
+        
+        topDialog.connect_signals({
             "destroy_passed_object" : self.close,
             "on_help_clicked"       : self.on_help_clicked,
+            "on_delete_event"       : self.close,
         })
 
-        window = topDialog.get_widget("top")
-        title = topDialog.get_widget("title")
+        window = topDialog.toplevel
+        title = topDialog.get_object("title")
         self.set_window(window, title, self.title)
 
-        self.markercombo = topDialog.get_widget("markercombo")
-        self.markerapply = topDialog.get_widget("markerapply")
+        self.markercombo = topDialog.get_object("markercombo")
+        self.markerapply = topDialog.get_object("markerapply")
         self.markercombo.set_sensitive(False)
         self.markerapply.set_sensitive(False)
         self.markerapply.connect('clicked', self.applyMarkerClicked)
 
     
         # start the progress indicator
-        self.progress = Utils.ProgressMeter(self.title,_('Starting'))
+        self.progress = ProgressMeter(self.title,_('Starting'))
 
         # setup the columns
         self.model = gtk.TreeStore(
@@ -113,7 +110,7 @@ class NotRelated(Tool.ActivePersonTool, ManagedWindow.ManagedWindow) :
 
         # note -- don't assign the model to the tree until it has been populated,
         # otherwise the screen updates are terribly slow while names are appended
-        self.treeView = topDialog.get_widget("treeview")
+        self.treeView = topDialog.get_object("treeview")
         col1 = gtk.TreeViewColumn(_('Name'),    gtk.CellRendererText(), text=0)
         col2 = gtk.TreeViewColumn(_('ID'),      gtk.CellRendererText(), text=1)
         col3 = gtk.TreeViewColumn(_('Parents'), gtk.CellRendererText(), text=2)
@@ -231,7 +228,7 @@ class NotRelated(Tool.ActivePersonTool, ManagedWindow.ManagedWindow) :
 
         # if more than 1 person is selected, use a progress indicator
         if rows > 1:
-            progress = Utils.ProgressMeter(self.title,_('Starting'))
+            progress = ProgressMeter(self.title,_('Starting'))
             #TRANS: no singular form needed, as rows is always > 1
             progress.set_pass(ngettext("Setting marker for %d person", 'Setting marker for %d people', \
                               rows) % rows, rows)
@@ -299,37 +296,38 @@ class NotRelated(Tool.ActivePersonTool, ManagedWindow.ManagedWindow) :
             for familyHandle in person.get_family_handle_list():
                 family = self.db.get_family_from_handle(familyHandle)
                 spouseHandle = ReportUtils.find_spouse(person, family)
-                if spouseHandle:
-                    if spouseHandle not in self.handlesOfPeopleAlreadyProcessed or spouseHandle not in self.handlesOfPeopleToBeProcessed:
-                        self.handlesOfPeopleToBeProcessed.add(spouseHandle)
+                if spouseHandle and \
+                  spouseHandle not in self.handlesOfPeopleAlreadyProcessed:
+                    self.handlesOfPeopleToBeProcessed.add(spouseHandle)
 
             # step 2 -- parents
             for familyHandle in person.get_parent_family_handle_list():
                 family = self.db.get_family_from_handle(familyHandle)
                 fatherHandle = family.get_father_handle()
                 motherHandle = family.get_mother_handle()
-                if fatherHandle:
-                    if fatherHandle not in self.handlesOfPeopleAlreadyProcessed or fatherHandle not in self.handlesOfPeopleToBeProcessed:
-                        self.handlesOfPeopleToBeProcessed.add(fatherHandle)
-                if motherHandle:
-                    if motherHandle not in self.handlesOfPeopleAlreadyProcessed or motherHandle not in self.handlesOfPeopleToBeProcessed:
-                        self.handlesOfPeopleToBeProcessed.add(motherHandle)
+                if fatherHandle and \
+                  fatherHandle not in self.handlesOfPeopleAlreadyProcessed:
+                    self.handlesOfPeopleToBeProcessed.add(fatherHandle)
+                if motherHandle and \
+                  motherHandle not in self.handlesOfPeopleAlreadyProcessed:
+                    self.handlesOfPeopleToBeProcessed.add(motherHandle)
 
             # step 3 -- children
             for familyHandle in person.get_family_handle_list():
                 family = self.db.get_family_from_handle(familyHandle)
                 for childRef in family.get_child_ref_list():
                     childHandle = childRef.ref
-                    if childHandle:
-                        if childHandle not in self.handlesOfPeopleAlreadyProcessed or childHandle not in self.handlesOfPeopleToBeProcessed:
-                            self.handlesOfPeopleToBeProcessed.add(childHandle)
+                    if childHandle and \
+                      childHandle not in self.handlesOfPeopleAlreadyProcessed:
+                        self.handlesOfPeopleToBeProcessed.add(childHandle)
 
 
     def findUnrelatedPeople(self) :
 
         # update our numbers
-        self.numberOfRelatedPeople   = len(self.handlesOfPeopleAlreadyProcessed)
-        self.numberOfUnrelatedPeople = self.numberOfPeopleInDatabase - self.numberOfRelatedPeople
+        self.numberOfRelatedPeople = len(self.handlesOfPeopleAlreadyProcessed)
+        self.numberOfUnrelatedPeople = self.numberOfPeopleInDatabase - \
+            self.numberOfRelatedPeople
 
         if self.numberOfUnrelatedPeople > 0:
             # we have at least 1 "unrelated" person to find
@@ -340,7 +338,7 @@ class NotRelated(Tool.ActivePersonTool, ManagedWindow.ManagedWindow) :
                     self.numberOfPeopleInDatabase) 
 
             # loop through everyone in the database
-            for handle in self.db.get_person_handles(False):
+            for handle in self.db.iter_person_handles():
 
                 self.progress.step()
 
@@ -433,24 +431,3 @@ class NotRelatedOptions(Tool.ToolOptions):
     def __init__(self, name, person_id=None):
         """ Initialize the options class """
         Tool.ToolOptions.__init__(self, name, person_id)
-
-#-------------------------------------------------------------------------
-#
-#
-#
-#-------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_tool(
-    name = 'not_related',
-    category = Tool.TOOL_UTILS,
-    tool_class = NotRelated,
-    options_class = NotRelatedOptions,
-    modes = PluginManager.TOOL_MODE_GUI,
-    translated_name = _("Not Related"),
-    status = _("Stable"),
-    author_name = "Stephane Charette",
-    author_email = "stephanecharette@gmail.com",
-    description = _("Find people who are not in any way related to the "
-                    "selected person")
-    )
-
