@@ -20,17 +20,17 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: RemoveUnused.py 13167 2009-09-08 06:35:01Z ldnp $
+# $Id: RemoveUnused.py 14104 2010-01-21 18:42:53Z gbritton $
 
-"Find unused objects and remove with the user's permission"
+"Find unused objects and remove with the user's permission."
 
 #-------------------------------------------------------------------------
 #
 # python modules
 #
 #-------------------------------------------------------------------------
-import os
-from gettext import gettext as _
+from __future__ import with_statement
+from gen.ggettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -46,9 +46,7 @@ log = logging.getLogger(".RemoveUnused")
 #
 #-------------------------------------------------------------------------
 import gtk
-from gtk import glade
 import gobject
-from gen.lib import StyledText
 
 #-------------------------------------------------------------------------
 #
@@ -58,16 +56,16 @@ from gen.lib import StyledText
 import Errors
 import ManagedWindow
 from DateHandler import displayer as _dd
-from BasicUtils import UpdateCallback
+from gen.updatecallback import UpdateCallback
 from PluginUtils import Tool
-from gen.plug import PluginManager
+from glade import Glade
 
 #-------------------------------------------------------------------------
 #
 # runTool
 #
 #-------------------------------------------------------------------------
-class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
+class RemoveUnused(Tool.Tool, ManagedWindow.ManagedWindow, UpdateCallback):
     MARK_COL       = 0
     OBJ_ID_COL     = 1
     OBJ_NAME_COL   = 2
@@ -82,8 +80,8 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
         if self.db.readonly:
             return
 
-        ManagedWindow.ManagedWindow.__init__(self, uistate,[],self.__class__)
-        UpdateCallback.__init__(self,self.uistate.pulse_progressbar)
+        ManagedWindow.ManagedWindow.__init__(self, uistate,[], self.__class__)
+        UpdateCallback.__init__(self, self.uistate.pulse_progressbar)
 
         self.dbstate = dbstate
         self.uistate = uistate
@@ -130,21 +128,18 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
         self.init_gui()
 
     def init_gui(self):
-        base = os.path.dirname(__file__)
-        self.glade_file = base + os.sep + "unused.glade"
+        self.top = Glade()
+        window = self.top.toplevel
+        self.set_window(window, self.top.get_object('title'), self.title)
 
-        self.top = glade.XML(self.glade_file,"unused","gramps")
-        window = self.top.get_widget("unused")
-        self.set_window(window,self.top.get_widget('title'),self.title)
-
-        self.events_box = self.top.get_widget('events_box')
-        self.sources_box = self.top.get_widget('sources_box')
-        self.places_box = self.top.get_widget('places_box')
-        self.media_box = self.top.get_widget('media_box')
-        self.repos_box = self.top.get_widget('repos_box')
-        self.notes_box = self.top.get_widget('notes_box')
-        self.find_button = self.top.get_widget('find_button')
-        self.remove_button = self.top.get_widget('remove_button')
+        self.events_box = self.top.get_object('events_box')
+        self.sources_box = self.top.get_object('sources_box')
+        self.places_box = self.top.get_object('places_box')
+        self.media_box = self.top.get_object('media_box')
+        self.repos_box = self.top.get_object('repos_box')
+        self.notes_box = self.top.get_object('notes_box')
+        self.find_button = self.top.get_object('find_button')
+        self.remove_button = self.top.get_object('remove_button')
 
         self.events_box.set_active(self.options.handler.options_dict['events'])
         self.sources_box.set_active(
@@ -155,19 +150,19 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
         self.repos_box.set_active(self.options.handler.options_dict['repos'])
         self.notes_box.set_active(self.options.handler.options_dict['notes'])
 
-        self.warn_tree = self.top.get_widget('warn_tree')
+        self.warn_tree = self.top.get_object('warn_tree')
         self.warn_tree.connect('button_press_event', self.double_click)
 
         self.selection = self.warn_tree.get_selection()
         
-        self.mark_button = self.top.get_widget('mark_button')
-        self.mark_button.connect('clicked',self.mark_clicked)
+        self.mark_button = self.top.get_object('mark_button')
+        self.mark_button.connect('clicked', self.mark_clicked)
 
-        self.unmark_button = self.top.get_widget('unmark_button')
-        self.unmark_button.connect('clicked',self.unmark_clicked)
+        self.unmark_button = self.top.get_object('unmark_button')
+        self.unmark_button.connect('clicked', self.unmark_clicked)
 
-        self.invert_button = self.top.get_widget('invert_button')
-        self.invert_button.connect('clicked',self.invert_clicked)
+        self.invert_button = self.top.get_object('invert_button')
+        self.invert_button.connect('clicked', self.invert_clicked)
 
         self.real_model = gtk.ListStore(gobject.TYPE_BOOLEAN, 
                                         gobject.TYPE_STRING, 
@@ -180,17 +175,17 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
         self.renderer = gtk.CellRendererText()
         self.img_renderer = gtk.CellRendererPixbuf()
         self.bool_renderer = gtk.CellRendererToggle()
-        self.bool_renderer.connect('toggled',self.selection_toggled)
+        self.bool_renderer.connect('toggled', self.selection_toggled)
 
         # Add mark column
-        mark_column = gtk.TreeViewColumn(_('Mark'),self.bool_renderer,
+        mark_column = gtk.TreeViewColumn(_('Mark'), self.bool_renderer,
                                            active=RemoveUnused.MARK_COL)
         mark_column.set_sort_column_id(RemoveUnused.MARK_COL)
         self.warn_tree.append_column(mark_column)
         
         # Add image column
         img_column = gtk.TreeViewColumn(None, self.img_renderer )
-        img_column.set_cell_data_func(self.img_renderer,self.get_image)
+        img_column.set_cell_data_func(self.img_renderer, self.get_image)
         self.warn_tree.append_column(img_column)        
 
         # Add column with object gramps_id
@@ -205,17 +200,18 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
         name_column.set_sort_column_id(RemoveUnused.OBJ_NAME_COL)
         self.warn_tree.append_column(name_column)
 
-        self.top.signal_autoconnect({
+        self.top.connect_signals({
             "destroy_passed_object"   : self.close,
             "on_remove_button_clicked": self.do_remove,
             "on_find_button_clicked"  : self.find,
+            "on_delete_event"         : self.close,
             })
 
-        self.dc_label = self.top.get_widget('dc_label')
+        self.dc_label = self.top.get_object('dc_label')
 
-        self.sensitive_list = [self.warn_tree,self.mark_button,
-                               self.unmark_button,self.invert_button,
-                               self.dc_label,self.remove_button]
+        self.sensitive_list = [self.warn_tree, self.mark_button,
+                               self.unmark_button, self.invert_button,
+                               self.dc_label, self.remove_button]
 
         for item in self.sensitive_list:
             item.set_sensitive(False)
@@ -223,7 +219,7 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
         self.show()
 
     def build_menu_names(self, obj):
-        return (self.title,None)
+        return (self.title, None)
 
     def find(self, obj):
         self.options.handler.options_dict['events'] = \
@@ -276,31 +272,26 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
                          'total_func' : self.db.get_number_of_notes},
             }
 
-        for the_type in tables.keys():
+        for the_type, the_func in tables.iteritems():
             if not self.options.handler.options_dict[the_type]:
                 # This table was not requested. Skip it.
                 continue
 
-            cursor = tables[the_type]['cursor_func']()
-            total = tables[the_type]['total_func']()
-            self.set_total(total)
-            item = cursor.first()
-            while item:
-                (handle,data) = item
-
-                hlist = [x for x in self.db.find_backlink_handles(handle)]
-                if len(hlist) == 0:
-                    self.add_results((the_type, handle, data))
-                item = cursor.next()
-                self.update()
-            cursor.close()
+            with the_func['cursor_func']() as cursor:
+                total = the_func['total_func']()
+                self.set_total(total)
+                fbh = self.db.find_backlink_handles
+                for handle, data in cursor:
+                    if not any(h for h in fbh(handle)):
+                        self.add_results((the_type, handle, data))
+                    self.update()
             self.reset()
 
     def do_remove(self, obj):
-        trans = self.db.transaction_begin("",batch=False)
+        trans = self.db.transaction_begin("", batch=False)
         self.db.disable_signals()
 
-        for row_num in range(len(self.real_model)-1,-1,-1):
+        for row_num in range(len(self.real_model)-1, -1, -1):
             path = (row_num,)
             row = self.real_model[path]
             if not row[RemoveUnused.MARK_COL]:
@@ -317,32 +308,32 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
         self.db.enable_signals()
         self.db.request_rebuild()
 
-    def selection_toggled(self,cell,path_string):
-        sort_path = tuple([int (i) for i in path_string.split(':')])
+    def selection_toggled(self, cell, path_string):
+        sort_path = tuple(map(int, path_string.split(':')))
         real_path = self.sort_model.convert_path_to_child_path(sort_path)
         row = self.real_model[real_path]
         row[RemoveUnused.MARK_COL] = not row[RemoveUnused.MARK_COL]
-        self.real_model.row_changed(real_path,row.iter)
+        self.real_model.row_changed(real_path, row.iter)
 
-    def mark_clicked(self,mark_button):
+    def mark_clicked(self, mark_button):
         for row_num in range(len(self.real_model)):
             path = (row_num,)
             row = self.real_model[path]
             row[RemoveUnused.MARK_COL] = True
 
-    def unmark_clicked(self,unmark_button):
+    def unmark_clicked(self, unmark_button):
         for row_num in range(len(self.real_model)):
             path = (row_num,)
             row = self.real_model[path]
             row[RemoveUnused.MARK_COL] = False
 
-    def invert_clicked(self,invert_button):
+    def invert_clicked(self, invert_button):
         for row_num in range(len(self.real_model)):
             path = (row_num,)
             row = self.real_model[path]
             row[RemoveUnused.MARK_COL] = not row[RemoveUnused.MARK_COL]
 
-    def double_click(self, obj,event):
+    def double_click(self, obj, event):
         if event.type == gtk.gdk._2BUTTON_PRESS and event.button == 1:
             (model, node) = self.selection.get_selected()
             if not node:
@@ -354,10 +345,10 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
             handle = row[RemoveUnused.OBJ_HANDLE_COL]
             self.call_editor(the_type, handle)
 
-    def call_editor(self,the_type, handle):
+    def call_editor(self, the_type, handle):
         try:
             obj = self.tables[the_type]['get_func'](handle)
-            editor_str = 'from Editors import %s as editor' \
+            editor_str = 'from gui.editors import %s as editor' \
                          % self.tables[the_type]['editor']
             exec(editor_str)            
             editor(self.dbstate, self.uistate, [], obj)
@@ -433,8 +424,7 @@ class RemoveUnused(Tool.Tool,ManagedWindow.ManagedWindow,UpdateCallback):
         text = " ".join(text.split())
 
         # if the note is too long, truncate it
-        # but first set type of text to unicode, otherwise the truncation
-        # might be wrong for non ascii characters
+        # but first set type of text to unicode, otherwise the sliceing might go wrong.
         text = unicode(text)
         if len(text) > 80:
             text = text[:80] + "..."
@@ -451,8 +441,8 @@ class CheckOptions(Tool.ToolOptions):
     Defines options and provides handling interface.
     """
 
-    def __init__(self, name,person_id=None):
-        Tool.ToolOptions.__init__(self, name,person_id)
+    def __init__(self, name, person_id=None):
+        Tool.ToolOptions.__init__(self, name, person_id)
 
         # Options specific for this report
         self.options_dict = {
@@ -483,22 +473,3 @@ class CheckOptions(Tool.ToolOptions):
                           ["Do not check notes","Check notes"],
                           True),
             }
-
-#------------------------------------------------------------------------
-#
-# 
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_tool(
-    name = 'remove_unused',
-    category = Tool.TOOL_DBFIX,
-    tool_class = RemoveUnused,
-    options_class = CheckOptions,
-    modes = PluginManager.TOOL_MODE_GUI,
-    translated_name = _("Remove Unused Objects"),
-    status = _("Stable"),
-    author_name = "Donald N. Allingham",
-    author_email = "don@gramps-project.org",
-    description = _("Removes unused objects from the database")
-    )
